//CONTROL LOCATIONS
typedef struct {
            u8 control_page;           //coefficient page location
            u8 control_base;           //coefficient base address within page
            u8 control_mute_flag;      //non-zero means muting required
            u8 control_string_index;   //string table index
} control; 


static control MUX_controls[] = {
};

static string MUX_control_names[] = {
};

static control VOLUME_controls[] = {
};

static string VOLUME_control_names[] = {
};

//INSTRUCTIONS & COEFFICIENTS
typedef struct {
    u8 reg_off;
    u8 reg_val;
} reg_value;

static string REG_Section_names[] = {
    "miniDSP_A_reg_values",
    "miniDSP_D_reg_values",
};

reg_value REG_Section_program[] = {
    {  0,0x00},
//			# reg[  0][  1] = 0x01	; Initialize the device through software reset
    {  1,0x01},
    {254,0x0A},
    {  0,0x01},
//			# reg[  1][  1] = 0x08	; Power up AVDD LDO; Disable weak AVDD to DVDD connection; Enable Master Analog Power Control, AVDD LDO Powered; Disable weak AVDD to DVDD connection
    {  1,0x08},
//			# reg[  1][  2] = 0x00	; Enable Master Analog Power Control
    {  2,0x00},
//			# reg[  1][ 71] = 0x32	; Set the input power-up time to 3.1ms
    { 71,0x32},
//			# reg[  1][123] = 0x01	; Set REF charging time to 40ms (automatic)
    {123,0x01},
    {255,0x00},
    {255,0x01},
    {  0,0x00},
//			# reg[  0][ 60] = 0x00    ; DAC prog Mode: miniDSP_A and miniDSP_D NOT powered up together, miniDSP_A used for signal processing
    { 60,0x00},
//			# reg[  0][ 61] = 0x00	; Use miniDSP_A for signal processing
    { 61,0x00},
//			# reg[  0][ 17] = 0x08	; 8x Interpolation
    { 17,0x08},
//			# reg[  0][ 23] = 0x04	; 4x Decimation
    { 23,0x04},
//			
    { 15,0x03},
//			
    { 16,0x88},
//			
    { 21,0x03},
//			
    { 22,0x88},
    {  0,0x08},
//			# reg[  8][  1] = 0x04	; adaptive mode for ADC
    {  1,0x04},
    {  0,0x2C},
//			# reg[ 44][  1] = 0x04	; adaptive mode for DAC
    {  1,0x04},
    {  0,0x00},
//			# reg[  0][  5] = 0x91	; P=1, R=1, J=8
    {  5,0x91},
//			# reg[  0][  6] = 0x08	; P=1, R=1, J=8
    {  6,0x08},
//			# reg[  0][  7] = 0x00	; D=0000 (MSB)
    {  7,0x00},
//			# reg[  0][  8] = 0x00	; D=0000 (LSB)
    {  8,0x00},
//			# reg[  0][  4] = 0x03	; PLL_clkin = MCLK, codec_clkin = PLL_CLK, PLL on
    {  4,0x03},
//			# reg[  0][ 12] = 0x88	; MDAC = 8, divider powered on
    { 12,0x88},
//			# reg[  0][ 13] = 0x00	; DOSR = 128 (MSB)
    { 13,0x00},
//			# reg[  0][ 14] = 0x80	; DOSR = 128 (LSB)
    { 14,0x80},
//			# reg[  0][ 18] = 0x02	; NADC = 2, divider powered off
    { 18,0x02},
//			# reg[  0][ 19] = 0x88	; MADC = 8, divider powered on
    { 19,0x88},
//			# reg[  0][ 20] = 0x80	; AOSR = 128
    { 20,0x80},
//			# reg[  0][ 11] = 0x82	; NDAC = 2, divider powered on
    { 11,0x82},
    {  0,0x01},
//			# reg[  1][ 51] = 0x40	; Mic Bias enabled, Source = Avdd, 1.25V
    { 51,0x40},
//			# reg[  1][ 52] = 0x40	; Route IN2L to LEFT_P with 10K input impedance; Route CM1L to LEFT_M with 10K input impedance; Route IN2R to RIGHT_P with 10K input impedance; Route IN1L to LEFT_P with 10K input impedance
    { 52,0x40},
//			# reg[  1][ 54] = 0x40	; Route CM1L to LEFT_M with 10K input impedance
    { 54,0x40},
//			# reg[  1][ 55] = 0x40	; Route IN1R to RIGHT_P with 10K input impedance
    { 55,0x40},
//			# reg[  1][ 57] = 0x40	; Route CM1R to RIGHT_M with 10K input impedance
    { 57,0x40},
//			# reg[  1][ 59] = 0x00	; Enable MicPGA_L Gain Control, 0dB
    { 59,0x00},
//			# reg[  1][ 60] = 0x00	; Enable MicPGA_R Gain Control, 0dB
    { 60,0x00},
    {  0,0x00},
//			# reg[  0][ 81] = 0xc0	; Power up LADC/RADC
    { 81,0xC0},
//			# reg[  0][ 82] = 0x00	; Unmute LADC/RADC
    { 82,0x00},
    {  0,0x01},
//			# reg[  1][ 20] = 0x25	; De-pop: 5 time constants, 6k resistance
    { 20,0x25},
//			# reg[  1][ 12] = 0x08	; Route LDAC to HPL
    { 12,0x08},
//			# reg[  1][ 13] = 0x08	; Route RDAC to HPR
    { 13,0x08},
//			# reg[  1][ 14] = 0x08	; Route LDAC to LOL
    { 14,0x08},
//			# reg[  1][ 15] = 0x08	; Route LDAC to LOR
    { 15,0x08},
    {  0,0x00},
//			# reg[  0][ 63] = 0xd4	; Power up LDAC/RDAC w/ soft stepping
    { 63,0xD4},
    {  0,0x01},
//			# reg[  1][ 16] = 0x00	; Unmute HPL driver, 0dB Gain
    { 16,0x00},
//			# reg[  1][ 17] = 0x00	; Unmute HPR driver, 0dB Gain
    { 17,0x00},
//			# reg[  1][ 18] = 0x00	; Unmute LOL driver, 0dB Gain
    { 18,0x00},
//			# reg[  1][ 19] = 0x00	; Unmute LOR driver, 0dB Gain
    { 19,0x00},
//			# reg[  1][  9] = 0x3c	; Power up HPL/HPR and LOL/LOR drivers
    {  9,0x3C},
    {  0,0x00},
//			# reg[  0][ 64] = 0x00	; Unmute LDAC/RDAC
    { 64,0x00},
//			# reg[0][82] = 0
    { 82,0x00},
//			# reg[0][83] = 0
    { 83,0x00},
//			# reg[0][86] = 32
    { 86,0x20},
//			# reg[0][87] = 254
    { 87,0xFE},
//			# reg[0][88] = 0
    { 88,0x00},
//			# reg[0][89] = 104
    { 89,0x68},
//			# reg[0][90] = 168
    { 90,0xA8},
//			# reg[0][91] = 6
    { 91,0x06},
//			# reg[0][92] = 0
    { 92,0x00},
//			# reg[0][84] = 0
    { 84,0x00},
//			# reg[0][94] = 32
    { 94,0x20},
//			# reg[0][95] = 254
    { 95,0xFE},
//			# reg[0][96] = 0
    { 96,0x00},
//			# reg[0][97] = 104
    { 97,0x68},
//			# reg[0][98] = 168
    { 98,0xA8},
//			# reg[0][99] = 6
    { 99,0x06},
//			# reg[0][100] = 0
    {100,0x00},
};

reg_value miniDSP_A_reg_values[] = {
    {  0,0x08},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x80},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x7F},
    { 37,0xFF},
    { 38,0xFF},
    { 39,0x00},
    { 40,0x40},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x9E},
    { 50,0x00},
    { 51,0x00},
    { 52,0xF7},
    { 53,0x10},
    { 54,0x00},
    { 55,0x00},
    { 56,0x26},
    { 57,0xF0},
    { 58,0x00},
    { 59,0x00},
    { 60,0x02},
    { 61,0x61},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x02},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xFC},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0xFD},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFF},
    { 77,0xE5},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0xA7},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFF},
    { 85,0xC7},
    { 86,0x00},
    { 87,0x00},
    { 88,0xFF},
    { 89,0xCE},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFE},
    { 94,0x00},
    { 95,0x00},
    { 96,0xFE},
    { 97,0xF7},
    { 98,0x00},
    { 99,0x00},
    {100,0xFF},
    {101,0x46},
    {102,0x00},
    {103,0x00},
    {104,0xFF},
    {105,0x22},
    {106,0x00},
    {107,0x00},
    {108,0xFF},
    {109,0x0F},
    {110,0x00},
    {111,0x00},
    {112,0xFA},
    {113,0x8C},
    {114,0x00},
    {115,0x00},
    {116,0xF5},
    {117,0x08},
    {118,0x00},
    {119,0x00},
    {120,0xFD},
    {121,0x92},
    {122,0x00},
    {123,0x00},
    {124,0xF3},
    {125,0xA3},
    {126,0x00},
    {127,0x00},
    {  0,0x09},
    {  8,0x03},
    {  9,0xB3},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x33},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x71},
    { 18,0x00},
    { 19,0x00},
    { 20,0x40},
    { 21,0x60},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0xE2},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0xC6},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x87},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x0F},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x0A},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x02},
    { 46,0x00},
    { 47,0x00},
    { 48,0x01},
    { 49,0x81},
    { 50,0x00},
    { 51,0x00},
    { 52,0x18},
    { 53,0x89},
    { 54,0x00},
    { 55,0x00},
    { 56,0x07},
    { 57,0xFB},
    { 58,0x00},
    { 59,0x00},
    { 60,0x03},
    { 61,0xBE},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x49},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xF2},
    { 70,0x00},
    { 71,0x00},
    { 72,0xF9},
    { 73,0xBA},
    { 74,0x00},
    { 75,0x00},
    { 76,0xF9},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0x68},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFE},
    { 85,0x2C},
    { 86,0x00},
    { 87,0x00},
    { 88,0xEB},
    { 89,0x8D},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x83},
    { 94,0x00},
    { 95,0x00},
    { 96,0x01},
    { 97,0xC3},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0xD3},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x33},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x32},
    {113,0x08},
    {114,0x00},
    {115,0x00},
    {116,0x0A},
    {117,0xFA},
    {118,0x00},
    {119,0x00},
    {120,0x54},
    {121,0x7B},
    {122,0x00},
    {123,0x00},
    {124,0xFF},
    {125,0x6B},
    {126,0x00},
    {127,0x00},
    {  0,0x0A},
    {  8,0xFF},
    {  9,0x03},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFC},
    { 13,0xC6},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF5},
    { 17,0x54},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x64},
    { 22,0x00},
    { 23,0x00},
    { 24,0x39},
    { 25,0x80},
    { 26,0x00},
    { 27,0x00},
    { 28,0x03},
    { 29,0x1C},
    { 30,0x00},
    { 31,0x00},
    { 32,0x03},
    { 33,0x2F},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x67},
    { 38,0x00},
    { 39,0x00},
    { 40,0x0F},
    { 41,0x73},
    { 42,0x00},
    { 43,0x00},
    { 44,0x2C},
    { 45,0x2B},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x4F},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0xAE},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x5C},
    { 59,0x00},
    {  0,0x1A},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x80},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x7F},
    { 37,0xFF},
    { 38,0xFF},
    { 39,0x00},
    { 40,0x40},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x9E},
    { 50,0x00},
    { 51,0x00},
    { 52,0xF7},
    { 53,0x10},
    { 54,0x00},
    { 55,0x00},
    { 56,0x26},
    { 57,0xF0},
    { 58,0x00},
    { 59,0x00},
    { 60,0x02},
    { 61,0x61},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x02},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xFC},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0xFD},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFF},
    { 77,0xE5},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0xA7},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFF},
    { 85,0xC7},
    { 86,0x00},
    { 87,0x00},
    { 88,0xFF},
    { 89,0xCE},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFE},
    { 94,0x00},
    { 95,0x00},
    { 96,0xFE},
    { 97,0xF7},
    { 98,0x00},
    { 99,0x00},
    {100,0xFF},
    {101,0x46},
    {102,0x00},
    {103,0x00},
    {104,0xFF},
    {105,0x22},
    {106,0x00},
    {107,0x00},
    {108,0xFF},
    {109,0x0F},
    {110,0x00},
    {111,0x00},
    {112,0xFA},
    {113,0x8C},
    {114,0x00},
    {115,0x00},
    {116,0xF5},
    {117,0x08},
    {118,0x00},
    {119,0x00},
    {120,0xFD},
    {121,0x92},
    {122,0x00},
    {123,0x00},
    {124,0xF3},
    {125,0xA3},
    {126,0x00},
    {127,0x00},
    {  0,0x1B},
    {  8,0x03},
    {  9,0xB3},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x33},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x71},
    { 18,0x00},
    { 19,0x00},
    { 20,0x40},
    { 21,0x60},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0xE2},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0xC6},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x87},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x0F},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x0A},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x02},
    { 46,0x00},
    { 47,0x00},
    { 48,0x01},
    { 49,0x81},
    { 50,0x00},
    { 51,0x00},
    { 52,0x18},
    { 53,0x89},
    { 54,0x00},
    { 55,0x00},
    { 56,0x07},
    { 57,0xFB},
    { 58,0x00},
    { 59,0x00},
    { 60,0x03},
    { 61,0xBE},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x49},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xF2},
    { 70,0x00},
    { 71,0x00},
    { 72,0xF9},
    { 73,0xBA},
    { 74,0x00},
    { 75,0x00},
    { 76,0xF9},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0x68},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFE},
    { 85,0x2C},
    { 86,0x00},
    { 87,0x00},
    { 88,0xEB},
    { 89,0x8D},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x83},
    { 94,0x00},
    { 95,0x00},
    { 96,0x01},
    { 97,0xC3},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0xD3},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x33},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x32},
    {113,0x08},
    {114,0x00},
    {115,0x00},
    {116,0x0A},
    {117,0xFA},
    {118,0x00},
    {119,0x00},
    {120,0x54},
    {121,0x7B},
    {122,0x00},
    {123,0x00},
    {124,0xFF},
    {125,0x6B},
    {126,0x00},
    {127,0x00},
    {  0,0x1C},
    {  8,0xFF},
    {  9,0x03},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFC},
    { 13,0xC6},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF5},
    { 17,0x54},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x64},
    { 22,0x00},
    { 23,0x00},
    { 24,0x39},
    { 25,0x80},
    { 26,0x00},
    { 27,0x00},
    { 28,0x03},
    { 29,0x1C},
    { 30,0x00},
    { 31,0x00},
    { 32,0x03},
    { 33,0x2F},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x67},
    { 38,0x00},
    { 39,0x00},
    { 40,0x0F},
    { 41,0x73},
    { 42,0x00},
    { 43,0x00},
    { 44,0x2C},
    { 45,0x2B},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x4F},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0xAE},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x5C},
    { 59,0x00},
    {  0,0x50},
    {  8,0x30},
    {  9,0x20},
    { 10,0x4E},
    { 11,0x00},
    { 12,0x30},
    { 13,0x20},
    { 14,0x9D},
    { 15,0x00},
    { 16,0x18},
    { 17,0x00},
    { 18,0x03},
    { 19,0x00},
    { 20,0x18},
    { 21,0x04},
    { 22,0x03},
    { 23,0x00},
    { 24,0x31},
    { 25,0x1B},
    { 26,0xFB},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x38},
    { 33,0x17},
    { 34,0xFB},
    { 35,0x00},
    { 36,0x88},
    { 37,0x17},
    { 38,0xFE},
    { 39,0x00},
    { 40,0x30},
    { 41,0x38},
    { 42,0x0C},
    { 43,0x00},
    { 44,0x38},
    { 45,0x34},
    { 46,0x07},
    { 47,0x00},
    { 48,0x38},
    { 49,0x34},
    { 50,0x03},
    { 51,0x00},
    { 52,0x38},
    { 53,0x30},
    { 54,0x08},
    { 55,0x00},
    { 56,0x38},
    { 57,0x30},
    { 58,0x02},
    { 59,0x00},
    { 60,0x38},
    { 61,0x2C},
    { 62,0x01},
    { 63,0x00},
    { 64,0x38},
    { 65,0x2C},
    { 66,0x09},
    { 67,0x00},
    { 68,0x38},
    { 69,0x28},
    { 70,0x0A},
    { 71,0x00},
    { 72,0xF0},
    { 73,0x28},
    { 74,0x00},
    { 75,0x00},
    { 76,0x30},
    { 77,0x28},
    { 78,0x59},
    { 79,0x00},
    { 80,0xF8},
    { 81,0x28},
    { 82,0x4F},
    { 83,0x00},
    { 84,0x20},
    { 85,0x00},
    { 86,0x2A},
    { 87,0x00},
    { 88,0x38},
    { 89,0x2C},
    { 90,0x50},
    { 91,0x00},
    { 92,0x38},
    { 93,0x2C},
    { 94,0x58},
    { 95,0x00},
    { 96,0x38},
    { 97,0x30},
    { 98,0x57},
    { 99,0x00},
    {100,0x38},
    {101,0x30},
    {102,0x51},
    {103,0x00},
    {104,0x38},
    {105,0x34},
    {106,0x56},
    {107,0x00},
    {108,0x38},
    {109,0x34},
    {110,0x52},
    {111,0x00},
    {112,0x38},
    {113,0x38},
    {114,0x5B},
    {115,0x00},
    {116,0x30},
    {117,0x3C},
    {118,0x29},
    {119,0x00},
    {120,0x38},
    {121,0x3C},
    {122,0x2A},
    {123,0x00},
    {124,0x20},
    {125,0x00},
    {126,0x79},
    {127,0x00},
    {  0,0x51},
    {  8,0x38},
    {  9,0x40},
    { 10,0x0E},
    { 11,0x00},
    { 12,0x38},
    { 13,0x40},
    { 14,0x45},
    { 15,0x00},
    { 16,0x38},
    { 17,0x44},
    { 18,0x2C},
    { 19,0x00},
    { 20,0x38},
    { 21,0x44},
    { 22,0x27},
    { 23,0x00},
    { 24,0x38},
    { 25,0x48},
    { 26,0x2E},
    { 27,0x00},
    { 28,0x38},
    { 29,0x48},
    { 30,0x25},
    { 31,0x00},
    { 32,0x38},
    { 33,0x4C},
    { 34,0x34},
    { 35,0x00},
    { 36,0x38},
    { 37,0x4C},
    { 38,0x1F},
    { 39,0x00},
    { 40,0x38},
    { 41,0x50},
    { 42,0x11},
    { 43,0x00},
    { 44,0x38},
    { 45,0x50},
    { 46,0x42},
    { 47,0x00},
    { 48,0x38},
    { 49,0x54},
    { 50,0x0F},
    { 51,0x00},
    { 52,0x38},
    { 53,0x54},
    { 54,0x44},
    { 55,0x00},
    { 56,0x38},
    { 57,0x58},
    { 58,0x35},
    { 59,0x00},
    { 60,0x38},
    { 61,0x58},
    { 62,0x1E},
    { 63,0x00},
    { 64,0x38},
    { 65,0x5C},
    { 66,0x30},
    { 67,0x00},
    { 68,0x38},
    { 69,0x5C},
    { 70,0x23},
    { 71,0x00},
    { 72,0x38},
    { 73,0x60},
    { 74,0x13},
    { 75,0x00},
    { 76,0x38},
    { 77,0x60},
    { 78,0x40},
    { 79,0x00},
    { 80,0x38},
    { 81,0x64},
    { 82,0x32},
    { 83,0x00},
    { 84,0x38},
    { 85,0x64},
    { 86,0x21},
    { 87,0x00},
    { 88,0x38},
    { 89,0x68},
    { 90,0x17},
    { 91,0x00},
    { 92,0x38},
    { 93,0x68},
    { 94,0x3C},
    { 95,0x00},
    { 96,0x38},
    { 97,0x6C},
    { 98,0x37},
    { 99,0x00},
    {100,0x38},
    {101,0x6C},
    {102,0x1C},
    {103,0x00},
    {104,0x38},
    {105,0x70},
    {106,0x15},
    {107,0x00},
    {108,0x38},
    {109,0x70},
    {110,0x3E},
    {111,0x00},
    {112,0x38},
    {113,0x74},
    {114,0x19},
    {115,0x00},
    {116,0x38},
    {117,0x74},
    {118,0x3A},
    {119,0x00},
    {120,0x38},
    {121,0x78},
    {122,0x16},
    {123,0x00},
    {124,0x38},
    {125,0x78},
    {126,0x3D},
    {127,0x00},
    {  0,0x52},
    {  8,0x38},
    {  9,0x7C},
    { 10,0x2D},
    { 11,0x00},
    { 12,0x38},
    { 13,0x7C},
    { 14,0x26},
    { 15,0x00},
    { 16,0x38},
    { 17,0x80},
    { 18,0x12},
    { 19,0x00},
    { 20,0x38},
    { 21,0x80},
    { 22,0x41},
    { 23,0x00},
    { 24,0x38},
    { 25,0x84},
    { 26,0x38},
    { 27,0x00},
    { 28,0x38},
    { 29,0x84},
    { 30,0x1B},
    { 31,0x00},
    { 32,0x38},
    { 33,0x88},
    { 34,0x31},
    { 35,0x00},
    { 36,0x38},
    { 37,0x88},
    { 38,0x22},
    { 39,0x00},
    { 40,0x38},
    { 41,0x8C},
    { 42,0x33},
    { 43,0x00},
    { 44,0x38},
    { 45,0x8C},
    { 46,0x20},
    { 47,0x00},
    { 48,0x38},
    { 49,0x90},
    { 50,0x2F},
    { 51,0x00},
    { 52,0x38},
    { 53,0x90},
    { 54,0x24},
    { 55,0x00},
    { 56,0x38},
    { 57,0x94},
    { 58,0x10},
    { 59,0x00},
    { 60,0x38},
    { 61,0x94},
    { 62,0x43},
    { 63,0x00},
    { 64,0x38},
    { 65,0x98},
    { 66,0x2B},
    { 67,0x00},
    { 68,0x38},
    { 69,0x98},
    { 70,0x28},
    { 71,0x00},
    { 72,0x38},
    { 73,0x9C},
    { 74,0x0D},
    { 75,0x00},
    { 76,0x38},
    { 77,0x9C},
    { 78,0x46},
    { 79,0x00},
    { 80,0x38},
    { 81,0xA0},
    { 82,0x14},
    { 83,0x00},
    { 84,0x38},
    { 85,0xA0},
    { 86,0x3F},
    { 87,0x00},
    { 88,0x38},
    { 89,0xA4},
    { 90,0x1A},
    { 91,0x00},
    { 92,0x38},
    { 93,0xA4},
    { 94,0x39},
    { 95,0x00},
    { 96,0x38},
    { 97,0xA8},
    { 98,0x18},
    { 99,0x00},
    {100,0x38},
    {101,0xA8},
    {102,0x3B},
    {103,0x00},
    {104,0x38},
    {105,0xAC},
    {106,0x36},
    {107,0x00},
    {108,0x38},
    {109,0xAC},
    {110,0x1D},
    {111,0x00},
    {112,0x08},
    {113,0x00},
    {114,0x0A},
    {115,0x00},
    {116,0x50},
    {117,0x04},
    {118,0x00},
    {119,0x00},
    {120,0x08},
    {121,0x04},
    {122,0x59},
    {123,0x00},
    {124,0x50},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x53},
    {  8,0x30},
    {  9,0x0C},
    { 10,0x47},
    { 11,0x00},
    { 12,0x38},
    { 13,0x10},
    { 14,0x49},
    { 15,0x00},
    { 16,0x98},
    { 17,0x08},
    { 18,0x46},
    { 19,0x00},
    { 20,0x60},
    { 21,0x00},
    { 22,0x49},
    { 23,0x00},
    { 24,0x38},
    { 25,0x04},
    { 26,0x4B},
    { 27,0x00},
    { 28,0x28},
    { 29,0x00},
    { 30,0x48},
    { 31,0x00},
    { 32,0x68},
    { 33,0x00},
    { 34,0x48},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x18},
    { 41,0x08},
    { 42,0x00},
    { 43,0x00},
    { 44,0x28},
    { 45,0x00},
    { 46,0x4A},
    { 47,0x00},
    { 48,0x31},
    { 49,0x1F},
    { 50,0xFB},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x38},
    { 57,0x17},
    { 58,0xFB},
    { 59,0x00},
    { 60,0x88},
    { 61,0x17},
    { 62,0xFE},
    { 63,0x00},
    { 64,0x30},
    { 65,0x38},
    { 66,0x54},
    { 67,0x00},
    { 68,0x38},
    { 69,0x34},
    { 70,0x4F},
    { 71,0x00},
    { 72,0x38},
    { 73,0x34},
    { 74,0x58},
    { 75,0x00},
    { 76,0x38},
    { 77,0x30},
    { 78,0x50},
    { 79,0x00},
    { 80,0x38},
    { 81,0x30},
    { 82,0x57},
    { 83,0x00},
    { 84,0x38},
    { 85,0x2C},
    { 86,0x56},
    { 87,0x00},
    { 88,0x38},
    { 89,0x2C},
    { 90,0x51},
    { 91,0x00},
    { 92,0x38},
    { 93,0x28},
    { 94,0x52},
    { 95,0x00},
    { 96,0xF8},
    { 97,0x28},
    { 98,0x55},
    { 99,0x00},
    {100,0x30},
    {101,0x28},
    {102,0x03},
    {103,0x00},
    {104,0xF0},
    {105,0x28},
    {106,0x06},
    {107,0x00},
    {108,0x20},
    {109,0x00},
    {110,0x5B},
    {111,0x00},
    {112,0x38},
    {113,0x2C},
    {114,0x07},
    {115,0x00},
    {116,0x38},
    {117,0x2C},
    {118,0x02},
    {119,0x00},
    {120,0x38},
    {121,0x30},
    {122,0x01},
    {123,0x00},
    {124,0x38},
    {125,0x30},
    {126,0x08},
    {127,0x00},
    {  0,0x54},
    {  8,0x38},
    {  9,0x34},
    { 10,0x00},
    { 11,0x00},
    { 12,0x38},
    { 13,0x34},
    { 14,0x09},
    { 15,0x00},
    { 16,0x38},
    { 17,0x38},
    { 18,0x05},
    { 19,0x00},
    { 20,0x30},
    { 21,0x3C},
    { 22,0x78},
    { 23,0x00},
    { 24,0x38},
    { 25,0x3C},
    { 26,0x79},
    { 27,0x00},
    { 28,0x20},
    { 29,0x00},
    { 30,0x0C},
    { 31,0x00},
    { 32,0x38},
    { 33,0x40},
    { 34,0x5D},
    { 35,0x00},
    { 36,0x38},
    { 37,0x40},
    { 38,0x94},
    { 39,0x00},
    { 40,0x38},
    { 41,0x44},
    { 42,0x7B},
    { 43,0x00},
    { 44,0x38},
    { 45,0x44},
    { 46,0x76},
    { 47,0x00},
    { 48,0x38},
    { 49,0x48},
    { 50,0x7D},
    { 51,0x00},
    { 52,0x38},
    { 53,0x48},
    { 54,0x74},
    { 55,0x00},
    { 56,0x38},
    { 57,0x4C},
    { 58,0x83},
    { 59,0x00},
    { 60,0x38},
    { 61,0x4C},
    { 62,0x6E},
    { 63,0x00},
    { 64,0x38},
    { 65,0x50},
    { 66,0x60},
    { 67,0x00},
    { 68,0x38},
    { 69,0x50},
    { 70,0x91},
    { 71,0x00},
    { 72,0x38},
    { 73,0x54},
    { 74,0x5E},
    { 75,0x00},
    { 76,0x38},
    { 77,0x54},
    { 78,0x93},
    { 79,0x00},
    { 80,0x38},
    { 81,0x58},
    { 82,0x84},
    { 83,0x00},
    { 84,0x38},
    { 85,0x58},
    { 86,0x6D},
    { 87,0x00},
    { 88,0x38},
    { 89,0x5C},
    { 90,0x7F},
    { 91,0x00},
    { 92,0x38},
    { 93,0x5C},
    { 94,0x72},
    { 95,0x00},
    { 96,0x38},
    { 97,0x60},
    { 98,0x62},
    { 99,0x00},
    {100,0x38},
    {101,0x60},
    {102,0x8F},
    {103,0x00},
    {104,0x38},
    {105,0x64},
    {106,0x81},
    {107,0x00},
    {108,0x38},
    {109,0x64},
    {110,0x70},
    {111,0x00},
    {112,0x38},
    {113,0x68},
    {114,0x66},
    {115,0x00},
    {116,0x38},
    {117,0x68},
    {118,0x8B},
    {119,0x00},
    {120,0x38},
    {121,0x6C},
    {122,0x86},
    {123,0x00},
    {124,0x38},
    {125,0x6C},
    {126,0x6B},
    {127,0x00},
    {  0,0x55},
    {  8,0x38},
    {  9,0x70},
    { 10,0x64},
    { 11,0x00},
    { 12,0x38},
    { 13,0x70},
    { 14,0x8D},
    { 15,0x00},
    { 16,0x38},
    { 17,0x74},
    { 18,0x68},
    { 19,0x00},
    { 20,0x38},
    { 21,0x74},
    { 22,0x89},
    { 23,0x00},
    { 24,0x38},
    { 25,0x78},
    { 26,0x65},
    { 27,0x00},
    { 28,0x38},
    { 29,0x78},
    { 30,0x8C},
    { 31,0x00},
    { 32,0x38},
    { 33,0x7C},
    { 34,0x7C},
    { 35,0x00},
    { 36,0x38},
    { 37,0x7C},
    { 38,0x75},
    { 39,0x00},
    { 40,0x38},
    { 41,0x80},
    { 42,0x61},
    { 43,0x00},
    { 44,0x38},
    { 45,0x80},
    { 46,0x90},
    { 47,0x00},
    { 48,0x38},
    { 49,0x84},
    { 50,0x87},
    { 51,0x00},
    { 52,0x38},
    { 53,0x84},
    { 54,0x6A},
    { 55,0x00},
    { 56,0x38},
    { 57,0x88},
    { 58,0x80},
    { 59,0x00},
    { 60,0x38},
    { 61,0x88},
    { 62,0x71},
    { 63,0x00},
    { 64,0x38},
    { 65,0x8C},
    { 66,0x82},
    { 67,0x00},
    { 68,0x38},
    { 69,0x8C},
    { 70,0x6F},
    { 71,0x00},
    { 72,0x38},
    { 73,0x90},
    { 74,0x7E},
    { 75,0x00},
    { 76,0x38},
    { 77,0x90},
    { 78,0x73},
    { 79,0x00},
    { 80,0x38},
    { 81,0x94},
    { 82,0x5F},
    { 83,0x00},
    { 84,0x38},
    { 85,0x94},
    { 86,0x92},
    { 87,0x00},
    { 88,0x38},
    { 89,0x98},
    { 90,0x7A},
    { 91,0x00},
    { 92,0x38},
    { 93,0x98},
    { 94,0x77},
    { 95,0x00},
    { 96,0x38},
    { 97,0x9C},
    { 98,0x5C},
    { 99,0x00},
    {100,0x38},
    {101,0x9C},
    {102,0x95},
    {103,0x00},
    {104,0x38},
    {105,0xA0},
    {106,0x63},
    {107,0x00},
    {108,0x38},
    {109,0xA0},
    {110,0x8E},
    {111,0x00},
    {112,0x38},
    {113,0xA4},
    {114,0x69},
    {115,0x00},
    {116,0x38},
    {117,0xA4},
    {118,0x88},
    {119,0x00},
    {120,0x38},
    {121,0xA8},
    {122,0x67},
    {123,0x00},
    {124,0x38},
    {125,0xA8},
    {126,0x8A},
    {127,0x00},
    {  0,0x56},
    {  8,0x38},
    {  9,0xAC},
    { 10,0x85},
    { 11,0x00},
    { 12,0x38},
    { 13,0xAC},
    { 14,0x6C},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x50},
    { 21,0x0C},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x50},
    { 29,0x08},
    { 30,0x00},
    { 31,0x00},
    { 32,0x30},
    { 33,0x0C},
    { 34,0x96},
    { 35,0x00},
    { 36,0x38},
    { 37,0x10},
    { 38,0x98},
    { 39,0x00},
    { 40,0x98},
    { 41,0x08},
    { 42,0x95},
    { 43,0x00},
    { 44,0x60},
    { 45,0x00},
    { 46,0x98},
    { 47,0x00},
    { 48,0x38},
    { 49,0x04},
    { 50,0x9A},
    { 51,0x00},
    { 52,0x28},
    { 53,0x00},
    { 54,0x97},
    { 55,0x00},
    { 56,0x68},
    { 57,0x00},
    { 58,0x97},
    { 59,0x00},
    { 60,0x58},
    { 61,0x14},
    { 62,0x97},
    { 63,0x00},
    { 64,0x18},
    { 65,0x0C},
    { 66,0x00},
    { 67,0x00},
    { 68,0x28},
    { 69,0x00},
    { 70,0x99},
    { 71,0x00},
    { 72,0x58},
    { 73,0x10},
    { 74,0x48},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x20},
    { 81,0xFC},
    { 82,0x9C},
    { 83,0x00},
    { 84,0x20},
    { 85,0xFC},
    { 86,0x4D},
    { 87,0x00},
    { 88,0x31},
    { 89,0x23},
    { 90,0xFB},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x38},
    { 97,0x17},
    { 98,0xFB},
    { 99,0x00},
    {100,0x88},
    {101,0x17},
    {102,0xFE},
    {103,0x00},
    {104,0x08},
    {105,0x00},
    {106,0x03},
    {107,0x00},
    {108,0x08},
    {109,0x04},
    {110,0x52},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x88},
    {117,0x03},
    {118,0xFF},
    {119,0x00},
};
#define miniDSP_A_reg_values_COEFF_START   0
#define miniDSP_A_reg_values_COEFF_SIZE    590
#define miniDSP_A_reg_values_INST_START    590
#define miniDSP_A_reg_values_INST_SIZE     839

reg_value miniDSP_D_reg_values[] = {
    {  0,0x2C},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x7F},
    { 21,0xFF},
    { 22,0xFF},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    {  0,0x3E},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x7F},
    { 21,0xFF},
    { 22,0xFF},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    {  0,0x98},
    {  8,0x88},
    {  9,0x03},
    { 10,0xFF},
    { 11,0x00},
};
#define miniDSP_D_reg_values_COEFF_START   0
#define miniDSP_D_reg_values_COEFF_SIZE    42
#define miniDSP_D_reg_values_INST_START    42
#define miniDSP_D_reg_values_INST_SIZE     5
