//CONTROL LOCATIONS
typedef struct {
            u8 control_page;           //coefficient page location
            u8 control_base;           //coefficient base address within page
            u8 control_mute_flag;      //non-zero means muting required
            u8 control_string_index;   //string table index
} control; 


static control MUX_controls[] = {
};

static string MUX_control_names[] = {
};

static control VOLUME_controls[] = {
};

static string VOLUME_control_names[] = {
};

//INSTRUCTIONS & COEFFICIENTS
typedef struct {
    u8 reg_off;
    u8 reg_val;
} reg_value;

static string REG_Section_names[] = {
    "miniDSP_A_reg_values",
    "miniDSP_D_reg_values",
};

reg_value REG_Section_program[] = {
    {  0,0x00},
//			# reg[  0][  1] = 0x01	; Initialize the device through software reset
    {  1,0x01},
    {254,0x0A},
    {  0,0x01},
//			# reg[  1][  1] = 0x08	; Power up AVDD LDO; Disable weak AVDD to DVDD connection; Enable Master Analog Power Control, AVDD LDO Powered; Disable weak AVDD to DVDD connection
    {  1,0x08},
//			# reg[  1][  2] = 0x00	; Enable Master Analog Power Control
    {  2,0x00},
//			# reg[  1][ 71] = 0x32	; Set the input power-up time to 3.1ms
    { 71,0x32},
//			# reg[  1][123] = 0x01	; Set REF charging time to 40ms (automatic)
    {123,0x01},
    {255,0x00},
    {255,0x01},
    {  0,0x00},
//			# reg[  0][ 60] = 0x00    ; DAC prog Mode: miniDSP_A and miniDSP_D NOT powered up together, miniDSP_A used for signal processing
    { 60,0x00},
//			# reg[  0][ 61] = 0x00	; Use miniDSP_A for signal processing
    { 61,0x00},
//			# reg[  0][ 17] = 0x08	; 8x Interpolation
    { 17,0x08},
//			# reg[  0][ 23] = 0x04	; 4x Decimation
    { 23,0x04},
//			
    { 15,0x03},
//			
    { 16,0x88},
//			
    { 21,0x03},
//			
    { 22,0x88},
    {  0,0x08},
//			# reg[  8][  1] = 0x04	; adaptive mode for ADC
    {  1,0x04},
    {  0,0x2C},
//			# reg[ 44][  1] = 0x04	; adaptive mode for DAC
    {  1,0x04},
    {  0,0x00},
//			# reg[  0][  5] = 0x91	; P=1, R=1, J=8
    {  5,0x91},
//			# reg[  0][  6] = 0x08	; P=1, R=1, J=8
    {  6,0x08},
//			# reg[  0][  7] = 0x00	; D=0000 (MSB)
    {  7,0x00},
//			# reg[  0][  8] = 0x00	; D=0000 (LSB)
    {  8,0x00},
//			# reg[  0][  4] = 0x03	; PLL_clkin = MCLK, codec_clkin = PLL_CLK, PLL on
    {  4,0x03},
//			# reg[  0][ 12] = 0x88	; MDAC = 8, divider powered on
    { 12,0x88},
//			# reg[  0][ 13] = 0x00	; DOSR = 128 (MSB)
    { 13,0x00},
//			# reg[  0][ 14] = 0x80	; DOSR = 128 (LSB)
    { 14,0x80},
//			# reg[  0][ 18] = 0x02	; NADC = 2, divider powered off
    { 18,0x02},
//			# reg[  0][ 19] = 0x88	; MADC = 8, divider powered on
    { 19,0x88},
//			# reg[  0][ 20] = 0x80	; AOSR = 128
    { 20,0x80},
//			# reg[  0][ 11] = 0x82	; NDAC = 2, divider powered on
    { 11,0x82},
    {  0,0x01},
//			# reg[  1][ 51] = 0x40	; Mic Bias enabled, Source = Avdd, 1.25V
    { 51,0x40},
//			# reg[  1][ 52] = 0x40	; Route IN2L to LEFT_P with 10K input impedance; Route CM1L to LEFT_M with 10K input impedance; Route IN2R to RIGHT_P with 10K input impedance; Route IN1L to LEFT_P with 10K input impedance
    { 52,0x40},
//			# reg[  1][ 54] = 0x40	; Route CM1L to LEFT_M with 10K input impedance
    { 54,0x40},
//			# reg[  1][ 55] = 0x40	; Route IN1R to RIGHT_P with 10K input impedance
    { 55,0x40},
//			# reg[  1][ 57] = 0x40	; Route CM1R to RIGHT_M with 10K input impedance
    { 57,0x40},
//			# reg[  1][ 59] = 0x00	; Enable MicPGA_L Gain Control, 0dB
    { 59,0x00},
//			# reg[  1][ 60] = 0x00	; Enable MicPGA_R Gain Control, 0dB
    { 60,0x00},
    {  0,0x00},
//			# reg[  0][ 81] = 0xc0	; Power up LADC/RADC
    { 81,0xC0},
//			# reg[  0][ 82] = 0x00	; Unmute LADC/RADC
    { 82,0x00},
    {  0,0x01},
//			# reg[  1][ 20] = 0x25	; De-pop: 5 time constants, 6k resistance
    { 20,0x25},
//			# reg[  1][ 12] = 0x08	; Route LDAC to HPL
    { 12,0x08},
//			# reg[  1][ 13] = 0x08	; Route RDAC to HPR
    { 13,0x08},
//			# reg[  1][ 14] = 0x08	; Route LDAC to LOL
    { 14,0x08},
//			# reg[  1][ 15] = 0x08	; Route LDAC to LOR
    { 15,0x08},
    {  0,0x00},
//			# reg[  0][ 63] = 0xd4	; Power up LDAC/RDAC w/ soft stepping
    { 63,0xD4},
    {  0,0x01},
//			# reg[  1][ 16] = 0x00	; Unmute HPL driver, 0dB Gain
    { 16,0x00},
//			# reg[  1][ 17] = 0x00	; Unmute HPR driver, 0dB Gain
    { 17,0x00},
//			# reg[  1][ 18] = 0x00	; Unmute LOL driver, 0dB Gain
    { 18,0x00},
//			# reg[  1][ 19] = 0x00	; Unmute LOR driver, 0dB Gain
    { 19,0x00},
//			# reg[  1][  9] = 0x3c	; Power up HPL/HPR and LOL/LOR drivers
    {  9,0x3C},
    {  0,0x00},
//			# reg[  0][ 64] = 0x00	; Unmute LDAC/RDAC
    { 64,0x00},
//			# reg[0][82] = 0
    { 82,0x00},
//			# reg[0][83] = 0
    { 83,0x00},
//			# reg[0][86] = 48
    { 86,0x30},
//			# reg[0][87] = 254
    { 87,0xFE},
//			# reg[0][88] = 0
    { 88,0x00},
//			# reg[0][89] = 104
    { 89,0x68},
//			# reg[0][90] = 168
    { 90,0xA8},
//			# reg[0][91] = 6
    { 91,0x06},
//			# reg[0][92] = 0
    { 92,0x00},
//			# reg[0][84] = 0
    { 84,0x00},
//			# reg[0][94] = 48
    { 94,0x30},
//			# reg[0][95] = 254
    { 95,0xFE},
//			# reg[0][96] = 0
    { 96,0x00},
//			# reg[0][97] = 104
    { 97,0x68},
//			# reg[0][98] = 168
    { 98,0xA8},
//			# reg[0][99] = 6
    { 99,0x06},
//			# reg[0][100] = 0
    {100,0x00},
};

reg_value miniDSP_A_reg_values[] = {
    {  0,0x08},
    {  8,0x7F},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x19},
    { 29,0x99},
    { 30,0x9A},
    { 31,0x00},
    { 32,0x19},
    { 33,0x99},
    { 34,0x9A},
    { 35,0x00},
    { 36,0x00},
    { 37,0x31},
    { 38,0x7F},
    { 39,0x00},
    { 40,0x06},
    { 41,0x66},
    { 42,0x66},
    { 43,0x00},
    { 44,0x00},
    { 45,0x20},
    { 46,0xBC},
    { 47,0x00},
    { 48,0x00},
    { 49,0x01},
    { 50,0xA3},
    { 51,0x00},
    { 52,0x00},
    { 53,0xCC},
    { 54,0xCC},
    { 55,0x00},
    { 56,0x08},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x08},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x01},
    { 66,0x48},
    { 67,0x00},
    { 68,0x3F},
    { 69,0xFC},
    { 70,0x94},
    { 71,0x00},
    { 72,0x01},
    { 73,0x6B},
    { 74,0x48},
    { 75,0x00},
    { 76,0x7D},
    { 77,0x29},
    { 78,0x70},
    { 79,0x00},
    { 80,0x7F},
    { 81,0xFF},
    { 82,0xFF},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFF},
    { 94,0xFF},
    { 95,0x00},
    { 96,0x80},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x7F},
    {101,0xFF},
    {102,0xFF},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0xFF},
    {113,0x9E},
    {114,0x00},
    {115,0x00},
    {116,0xF7},
    {117,0x10},
    {118,0x00},
    {119,0x00},
    {120,0x26},
    {121,0xF0},
    {122,0x00},
    {123,0x00},
    {124,0x02},
    {125,0x61},
    {126,0x00},
    {127,0x00},
    {  0,0x09},
    {  8,0x40},
    {  9,0x02},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xFC},
    { 14,0x00},
    { 15,0x00},
    { 16,0xFF},
    { 17,0xFD},
    { 18,0x00},
    { 19,0x00},
    { 20,0xFF},
    { 21,0xE5},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0xA7},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xC7},
    { 30,0x00},
    { 31,0x00},
    { 32,0xFF},
    { 33,0xCE},
    { 34,0x00},
    { 35,0x00},
    { 36,0xFF},
    { 37,0xFE},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFE},
    { 41,0xF7},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0x46},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x22},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x0F},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFA},
    { 57,0x8C},
    { 58,0x00},
    { 59,0x00},
    { 60,0xF5},
    { 61,0x08},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFD},
    { 65,0x92},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF3},
    { 69,0xA3},
    { 70,0x00},
    { 71,0x00},
    { 72,0x03},
    { 73,0xB3},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x33},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x71},
    { 82,0x00},
    { 83,0x00},
    { 84,0x40},
    { 85,0x60},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0xE2},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0xC6},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x87},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x0F},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x0A},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x81},
    {114,0x00},
    {115,0x00},
    {116,0x18},
    {117,0x89},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xFB},
    {122,0x00},
    {123,0x00},
    {124,0x03},
    {125,0xBE},
    {126,0x00},
    {127,0x00},
    {  0,0x0A},
    {  8,0x00},
    {  9,0x49},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xF2},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF9},
    { 17,0xBA},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0x68},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x2C},
    { 30,0x00},
    { 31,0x00},
    { 32,0xEB},
    { 33,0x8D},
    { 34,0x00},
    { 35,0x00},
    { 36,0x03},
    { 37,0x83},
    { 38,0x00},
    { 39,0x00},
    { 40,0x01},
    { 41,0xC3},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0xD3},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x33},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x02},
    { 54,0x00},
    { 55,0x00},
    { 56,0x32},
    { 57,0x08},
    { 58,0x00},
    { 59,0x00},
    { 60,0x0A},
    { 61,0xFA},
    { 62,0x00},
    { 63,0x00},
    { 64,0x54},
    { 65,0x7B},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x6B},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x03},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFC},
    { 77,0xC6},
    { 78,0x00},
    { 79,0x00},
    { 80,0xF5},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xF9},
    { 85,0x64},
    { 86,0x00},
    { 87,0x00},
    { 88,0x39},
    { 89,0x80},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x1C},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0x2F},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x67},
    {102,0x00},
    {103,0x00},
    {104,0x0F},
    {105,0x73},
    {106,0x00},
    {107,0x00},
    {108,0x2C},
    {109,0x2B},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x80},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x7F},
    {121,0xFF},
    {122,0xFF},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x0B},
    {  8,0x0C},
    {  9,0xCC},
    { 10,0xCD},
    { 11,0x00},
    { 12,0x9B},
    { 13,0x78},
    { 14,0x13},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x34},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0xAE},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x5C},
    { 27,0x00},
    {  0,0x1A},
    {  8,0x7F},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x19},
    { 29,0x99},
    { 30,0x9A},
    { 31,0x00},
    { 32,0x19},
    { 33,0x99},
    { 34,0x9A},
    { 35,0x00},
    { 36,0x00},
    { 37,0x31},
    { 38,0x7F},
    { 39,0x00},
    { 40,0x06},
    { 41,0x66},
    { 42,0x66},
    { 43,0x00},
    { 44,0x00},
    { 45,0x20},
    { 46,0xBC},
    { 47,0x00},
    { 48,0x00},
    { 49,0x01},
    { 50,0xA3},
    { 51,0x00},
    { 52,0x00},
    { 53,0xCC},
    { 54,0xCC},
    { 55,0x00},
    { 56,0x08},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x08},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x01},
    { 66,0x48},
    { 67,0x00},
    { 68,0x3F},
    { 69,0xFC},
    { 70,0x94},
    { 71,0x00},
    { 72,0x01},
    { 73,0x6B},
    { 74,0x48},
    { 75,0x00},
    { 76,0x7D},
    { 77,0x29},
    { 78,0x70},
    { 79,0x00},
    { 80,0x7F},
    { 81,0xFF},
    { 82,0xFF},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFF},
    { 94,0xFF},
    { 95,0x00},
    { 96,0x80},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x7F},
    {101,0xFF},
    {102,0xFF},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0xFF},
    {113,0x9E},
    {114,0x00},
    {115,0x00},
    {116,0xF7},
    {117,0x10},
    {118,0x00},
    {119,0x00},
    {120,0x26},
    {121,0xF0},
    {122,0x00},
    {123,0x00},
    {124,0x02},
    {125,0x61},
    {126,0x00},
    {127,0x00},
    {  0,0x1B},
    {  8,0x40},
    {  9,0x02},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xFC},
    { 14,0x00},
    { 15,0x00},
    { 16,0xFF},
    { 17,0xFD},
    { 18,0x00},
    { 19,0x00},
    { 20,0xFF},
    { 21,0xE5},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0xA7},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xC7},
    { 30,0x00},
    { 31,0x00},
    { 32,0xFF},
    { 33,0xCE},
    { 34,0x00},
    { 35,0x00},
    { 36,0xFF},
    { 37,0xFE},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFE},
    { 41,0xF7},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0x46},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x22},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x0F},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFA},
    { 57,0x8C},
    { 58,0x00},
    { 59,0x00},
    { 60,0xF5},
    { 61,0x08},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFD},
    { 65,0x92},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF3},
    { 69,0xA3},
    { 70,0x00},
    { 71,0x00},
    { 72,0x03},
    { 73,0xB3},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x33},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x71},
    { 82,0x00},
    { 83,0x00},
    { 84,0x40},
    { 85,0x60},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0xE2},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0xC6},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x87},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x0F},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x0A},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x81},
    {114,0x00},
    {115,0x00},
    {116,0x18},
    {117,0x89},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xFB},
    {122,0x00},
    {123,0x00},
    {124,0x03},
    {125,0xBE},
    {126,0x00},
    {127,0x00},
    {  0,0x1C},
    {  8,0x00},
    {  9,0x49},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xF2},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF9},
    { 17,0xBA},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0x68},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x2C},
    { 30,0x00},
    { 31,0x00},
    { 32,0xEB},
    { 33,0x8D},
    { 34,0x00},
    { 35,0x00},
    { 36,0x03},
    { 37,0x83},
    { 38,0x00},
    { 39,0x00},
    { 40,0x01},
    { 41,0xC3},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0xD3},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x33},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x02},
    { 54,0x00},
    { 55,0x00},
    { 56,0x32},
    { 57,0x08},
    { 58,0x00},
    { 59,0x00},
    { 60,0x0A},
    { 61,0xFA},
    { 62,0x00},
    { 63,0x00},
    { 64,0x54},
    { 65,0x7B},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x6B},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x03},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFC},
    { 77,0xC6},
    { 78,0x00},
    { 79,0x00},
    { 80,0xF5},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xF9},
    { 85,0x64},
    { 86,0x00},
    { 87,0x00},
    { 88,0x39},
    { 89,0x80},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x1C},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0x2F},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x67},
    {102,0x00},
    {103,0x00},
    {104,0x0F},
    {105,0x73},
    {106,0x00},
    {107,0x00},
    {108,0x2C},
    {109,0x2B},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x80},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x7F},
    {121,0xFF},
    {122,0xFF},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x1D},
    {  8,0x0C},
    {  9,0xCC},
    { 10,0xCD},
    { 11,0x00},
    { 12,0x9B},
    { 13,0x78},
    { 14,0x13},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x34},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0xAE},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x5C},
    { 27,0x00},
    {  0,0x50},
    {  8,0x31},
    {  9,0x58},
    { 10,0x9D},
    { 11,0x00},
    { 12,0x30},
    { 13,0x10},
    { 14,0xA7},
    { 15,0x00},
    { 16,0xD8},
    { 17,0x0C},
    { 18,0xA6},
    { 19,0x00},
    { 20,0x20},
    { 21,0x10},
    { 22,0xA2},
    { 23,0x00},
    { 24,0x38},
    { 25,0x08},
    { 26,0xA4},
    { 27,0x00},
    { 28,0xD8},
    { 29,0x04},
    { 30,0xA3},
    { 31,0x00},
    { 32,0x38},
    { 33,0x00},
    { 34,0xA2},
    { 35,0x00},
    { 36,0x31},
    { 37,0x5C},
    { 38,0xA0},
    { 39,0x00},
    { 40,0x38},
    { 41,0x14},
    { 42,0xA0},
    { 43,0x00},
    { 44,0x20},
    { 45,0x00},
    { 46,0xA5},
    { 47,0x00},
    { 48,0x49},
    { 49,0x5C},
    { 50,0x00},
    { 51,0x00},
    { 52,0x68},
    { 53,0x14},
    { 54,0xA5},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x49},
    { 61,0x6C},
    { 62,0x00},
    { 63,0x00},
    { 64,0x20},
    { 65,0x00},
    { 66,0x9F},
    { 67,0x00},
    { 68,0x38},
    { 69,0x2B},
    { 70,0xFB},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x20},
    { 77,0x04},
    { 78,0x9E},
    { 79,0x00},
    { 80,0x88},
    { 81,0x14},
    { 82,0x35},
    { 83,0x00},
    { 84,0x31},
    { 85,0x60},
    { 86,0x9E},
    { 87,0x00},
    { 88,0x38},
    { 89,0x27},
    { 90,0xFB},
    { 91,0x00},
    { 92,0x31},
    { 93,0x60},
    { 94,0x9E},
    { 95,0x00},
    { 96,0x38},
    { 97,0x23},
    { 98,0xFB},
    { 99,0x00},
    {100,0x88},
    {101,0x14},
    {102,0x26},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x20},
    {109,0x00},
    {110,0xA1},
    {111,0x00},
    {112,0x61},
    {113,0x5C},
    {114,0xA1},
    {115,0x00},
    {116,0x38},
    {117,0x2F},
    {118,0xFB},
    {119,0x00},
    {120,0x31},
    {121,0x5C},
    {122,0xA1},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x51},
    {  8,0x88},
    {  9,0x14},
    { 10,0x24},
    { 11,0x00},
    { 12,0x88},
    { 13,0x18},
    { 14,0x0F},
    { 15,0x00},
    { 16,0x30},
    { 17,0x33},
    { 18,0xFB},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x49},
    { 25,0x64},
    { 26,0x02},
    { 27,0x00},
    { 28,0x38},
    { 29,0x3C},
    { 30,0xA9},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x20},
    { 37,0x00},
    { 38,0xA1},
    { 39,0x00},
    { 40,0x88},
    { 41,0x14},
    { 42,0x03},
    { 43,0x00},
    { 44,0x30},
    { 45,0x3C},
    { 46,0xA9},
    { 47,0x00},
    { 48,0x30},
    { 49,0x1B},
    { 50,0xFB},
    { 51,0x00},
    { 52,0x88},
    { 53,0x00},
    { 54,0x03},
    { 55,0x00},
    { 56,0x31},
    { 57,0x5C},
    { 58,0xA1},
    { 59,0x00},
    { 60,0x30},
    { 61,0x1B},
    { 62,0xFB},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0x04},
    { 70,0xA8},
    { 71,0x00},
    { 72,0x88},
    { 73,0x00},
    { 74,0x32},
    { 75,0x00},
    { 76,0x30},
    { 77,0x37},
    { 78,0xFB},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x49},
    { 85,0x64},
    { 86,0x02},
    { 87,0x00},
    { 88,0x38},
    { 89,0x38},
    { 90,0xA9},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x20},
    { 97,0x00},
    { 98,0xA1},
    { 99,0x00},
    {100,0x88},
    {101,0x18},
    {102,0x03},
    {103,0x00},
    {104,0x30},
    {105,0x38},
    {106,0xA9},
    {107,0x00},
    {108,0x30},
    {109,0x1F},
    {110,0xFB},
    {111,0x00},
    {112,0x88},
    {113,0x00},
    {114,0x03},
    {115,0x00},
    {116,0x31},
    {117,0x5C},
    {118,0xA1},
    {119,0x00},
    {120,0x30},
    {121,0x1F},
    {122,0xFB},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x52},
    {  8,0x20},
    {  9,0x04},
    { 10,0xA8},
    { 11,0x00},
    { 12,0x88},
    { 13,0x00},
    { 14,0x23},
    { 15,0x00},
    { 16,0x31},
    { 17,0x64},
    { 18,0xA9},
    { 19,0x00},
    { 20,0x30},
    { 21,0x1F},
    { 22,0xFB},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x20},
    { 29,0x04},
    { 30,0xA8},
    { 31,0x00},
    { 32,0x88},
    { 33,0x00},
    { 34,0x0F},
    { 35,0x00},
    { 36,0x31},
    { 37,0x64},
    { 38,0xA9},
    { 39,0x00},
    { 40,0x30},
    { 41,0x1F},
    { 42,0xFB},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x20},
    { 49,0x04},
    { 50,0xA8},
    { 51,0x00},
    { 52,0x88},
    { 53,0x00},
    { 54,0x11},
    { 55,0x00},
    { 56,0x31},
    { 57,0x5F},
    { 58,0xFB},
    { 59,0x00},
    { 60,0x30},
    { 61,0x1B},
    { 62,0xFB},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0xF8},
    { 70,0xA8},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x00},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x53},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x41},
    { 37,0x68},
    { 38,0x02},
    { 39,0x00},
    { 40,0x31},
    { 41,0x5C},
    { 42,0xAB},
    { 43,0x00},
    { 44,0x39},
    { 45,0x68},
    { 46,0xAB},
    { 47,0x00},
    { 48,0x39},
    { 49,0x68},
    { 50,0xA8},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x49},
    { 57,0x5C},
    { 58,0x00},
    { 59,0x00},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0x00},
    { 70,0xAA},
    { 71,0x00},
    { 72,0x41},
    { 73,0x58},
    { 74,0x00},
    { 75,0x00},
    { 76,0x30},
    { 77,0x60},
    { 78,0x4E},
    { 79,0x00},
    { 80,0x30},
    { 81,0x60},
    { 82,0xA2},
    { 83,0x00},
    { 84,0x18},
    { 85,0x00},
    { 86,0x03},
    { 87,0x00},
    { 88,0x18},
    { 89,0x04},
    { 90,0x03},
    { 91,0x00},
    { 92,0x31},
    { 93,0x73},
    { 94,0xFB},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x38},
    {101,0x57},
    {102,0xFB},
    {103,0x00},
    {104,0x88},
    {105,0x17},
    {106,0xFE},
    {107,0x00},
    {108,0x30},
    {109,0x78},
    {110,0x0C},
    {111,0x00},
    {112,0x38},
    {113,0x74},
    {114,0x07},
    {115,0x00},
    {116,0x38},
    {117,0x74},
    {118,0x03},
    {119,0x00},
    {120,0x38},
    {121,0x70},
    {122,0x08},
    {123,0x00},
    {124,0x38},
    {125,0x70},
    {126,0x02},
    {127,0x00},
    {  0,0x54},
    {  8,0x38},
    {  9,0x6C},
    { 10,0x01},
    { 11,0x00},
    { 12,0x38},
    { 13,0x6C},
    { 14,0x09},
    { 15,0x00},
    { 16,0x38},
    { 17,0x68},
    { 18,0x0A},
    { 19,0x00},
    { 20,0xF0},
    { 21,0x68},
    { 22,0x00},
    { 23,0x00},
    { 24,0x30},
    { 25,0x68},
    { 26,0x59},
    { 27,0x00},
    { 28,0xF8},
    { 29,0x68},
    { 30,0x4F},
    { 31,0x00},
    { 32,0x20},
    { 33,0x00},
    { 34,0x2A},
    { 35,0x00},
    { 36,0x38},
    { 37,0x6C},
    { 38,0x50},
    { 39,0x00},
    { 40,0x38},
    { 41,0x6C},
    { 42,0x58},
    { 43,0x00},
    { 44,0x38},
    { 45,0x70},
    { 46,0x57},
    { 47,0x00},
    { 48,0x38},
    { 49,0x70},
    { 50,0x51},
    { 51,0x00},
    { 52,0x38},
    { 53,0x74},
    { 54,0x56},
    { 55,0x00},
    { 56,0x38},
    { 57,0x74},
    { 58,0x52},
    { 59,0x00},
    { 60,0x38},
    { 61,0x78},
    { 62,0x5B},
    { 63,0x00},
    { 64,0x30},
    { 65,0x7C},
    { 66,0x29},
    { 67,0x00},
    { 68,0x38},
    { 69,0x7C},
    { 70,0x2A},
    { 71,0x00},
    { 72,0x20},
    { 73,0x00},
    { 74,0x79},
    { 75,0x00},
    { 76,0x38},
    { 77,0x80},
    { 78,0x0E},
    { 79,0x00},
    { 80,0x38},
    { 81,0x80},
    { 82,0x45},
    { 83,0x00},
    { 84,0x38},
    { 85,0x84},
    { 86,0x2C},
    { 87,0x00},
    { 88,0x38},
    { 89,0x84},
    { 90,0x27},
    { 91,0x00},
    { 92,0x38},
    { 93,0x88},
    { 94,0x2E},
    { 95,0x00},
    { 96,0x38},
    { 97,0x88},
    { 98,0x25},
    { 99,0x00},
    {100,0x38},
    {101,0x8C},
    {102,0x34},
    {103,0x00},
    {104,0x38},
    {105,0x8C},
    {106,0x1F},
    {107,0x00},
    {108,0x38},
    {109,0x90},
    {110,0x11},
    {111,0x00},
    {112,0x38},
    {113,0x90},
    {114,0x42},
    {115,0x00},
    {116,0x38},
    {117,0x94},
    {118,0x0F},
    {119,0x00},
    {120,0x38},
    {121,0x94},
    {122,0x44},
    {123,0x00},
    {124,0x38},
    {125,0x98},
    {126,0x35},
    {127,0x00},
    {  0,0x55},
    {  8,0x38},
    {  9,0x98},
    { 10,0x1E},
    { 11,0x00},
    { 12,0x38},
    { 13,0x9C},
    { 14,0x30},
    { 15,0x00},
    { 16,0x38},
    { 17,0x9C},
    { 18,0x23},
    { 19,0x00},
    { 20,0x38},
    { 21,0xA0},
    { 22,0x13},
    { 23,0x00},
    { 24,0x38},
    { 25,0xA0},
    { 26,0x40},
    { 27,0x00},
    { 28,0x38},
    { 29,0xA4},
    { 30,0x32},
    { 31,0x00},
    { 32,0x38},
    { 33,0xA4},
    { 34,0x21},
    { 35,0x00},
    { 36,0x38},
    { 37,0xA8},
    { 38,0x17},
    { 39,0x00},
    { 40,0x38},
    { 41,0xA8},
    { 42,0x3C},
    { 43,0x00},
    { 44,0x38},
    { 45,0xAC},
    { 46,0x37},
    { 47,0x00},
    { 48,0x38},
    { 49,0xAC},
    { 50,0x1C},
    { 51,0x00},
    { 52,0x38},
    { 53,0xB0},
    { 54,0x15},
    { 55,0x00},
    { 56,0x38},
    { 57,0xB0},
    { 58,0x3E},
    { 59,0x00},
    { 60,0x38},
    { 61,0xB4},
    { 62,0x19},
    { 63,0x00},
    { 64,0x38},
    { 65,0xB4},
    { 66,0x3A},
    { 67,0x00},
    { 68,0x38},
    { 69,0xB8},
    { 70,0x16},
    { 71,0x00},
    { 72,0x38},
    { 73,0xB8},
    { 74,0x3D},
    { 75,0x00},
    { 76,0x38},
    { 77,0xBC},
    { 78,0x2D},
    { 79,0x00},
    { 80,0x38},
    { 81,0xBC},
    { 82,0x26},
    { 83,0x00},
    { 84,0x38},
    { 85,0xC0},
    { 86,0x12},
    { 87,0x00},
    { 88,0x38},
    { 89,0xC0},
    { 90,0x41},
    { 91,0x00},
    { 92,0x38},
    { 93,0xC4},
    { 94,0x38},
    { 95,0x00},
    { 96,0x38},
    { 97,0xC4},
    { 98,0x1B},
    { 99,0x00},
    {100,0x38},
    {101,0xC8},
    {102,0x31},
    {103,0x00},
    {104,0x38},
    {105,0xC8},
    {106,0x22},
    {107,0x00},
    {108,0x38},
    {109,0xCC},
    {110,0x33},
    {111,0x00},
    {112,0x38},
    {113,0xCC},
    {114,0x20},
    {115,0x00},
    {116,0x38},
    {117,0xD0},
    {118,0x2F},
    {119,0x00},
    {120,0x38},
    {121,0xD0},
    {122,0x24},
    {123,0x00},
    {124,0x38},
    {125,0xD4},
    {126,0x10},
    {127,0x00},
    {  0,0x56},
    {  8,0x38},
    {  9,0xD4},
    { 10,0x43},
    { 11,0x00},
    { 12,0x38},
    { 13,0xD8},
    { 14,0x2B},
    { 15,0x00},
    { 16,0x38},
    { 17,0xD8},
    { 18,0x28},
    { 19,0x00},
    { 20,0x38},
    { 21,0xDC},
    { 22,0x0D},
    { 23,0x00},
    { 24,0x38},
    { 25,0xDC},
    { 26,0x46},
    { 27,0x00},
    { 28,0x38},
    { 29,0xE0},
    { 30,0x14},
    { 31,0x00},
    { 32,0x38},
    { 33,0xE0},
    { 34,0x3F},
    { 35,0x00},
    { 36,0x38},
    { 37,0xE4},
    { 38,0x1A},
    { 39,0x00},
    { 40,0x38},
    { 41,0xE4},
    { 42,0x39},
    { 43,0x00},
    { 44,0x38},
    { 45,0xE8},
    { 46,0x18},
    { 47,0x00},
    { 48,0x38},
    { 49,0xE8},
    { 50,0x3B},
    { 51,0x00},
    { 52,0x38},
    { 53,0xEC},
    { 54,0x36},
    { 55,0x00},
    { 56,0x38},
    { 57,0xEC},
    { 58,0x1D},
    { 59,0x00},
    { 60,0x08},
    { 61,0x00},
    { 62,0x0A},
    { 63,0x00},
    { 64,0x50},
    { 65,0x04},
    { 66,0x00},
    { 67,0x00},
    { 68,0x08},
    { 69,0x04},
    { 70,0x59},
    { 71,0x00},
    { 72,0x50},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x30},
    { 77,0x4C},
    { 78,0x47},
    { 79,0x00},
    { 80,0x38},
    { 81,0x50},
    { 82,0x49},
    { 83,0x00},
    { 84,0x98},
    { 85,0x48},
    { 86,0x46},
    { 87,0x00},
    { 88,0x60},
    { 89,0x40},
    { 90,0x49},
    { 91,0x00},
    { 92,0x38},
    { 93,0x44},
    { 94,0x4B},
    { 95,0x00},
    { 96,0x28},
    { 97,0x00},
    { 98,0x48},
    { 99,0x00},
    {100,0x68},
    {101,0x40},
    {102,0x48},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x18},
    {109,0x08},
    {110,0x00},
    {111,0x00},
    {112,0x28},
    {113,0x00},
    {114,0x4A},
    {115,0x00},
    {116,0x31},
    {117,0x77},
    {118,0xFB},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x38},
    {125,0x57},
    {126,0xFB},
    {127,0x00},
    {  0,0x57},
    {  8,0x88},
    {  9,0x17},
    { 10,0xFE},
    { 11,0x00},
    { 12,0x30},
    { 13,0x78},
    { 14,0x54},
    { 15,0x00},
    { 16,0x38},
    { 17,0x74},
    { 18,0x4F},
    { 19,0x00},
    { 20,0x38},
    { 21,0x74},
    { 22,0x58},
    { 23,0x00},
    { 24,0x38},
    { 25,0x70},
    { 26,0x50},
    { 27,0x00},
    { 28,0x38},
    { 29,0x70},
    { 30,0x57},
    { 31,0x00},
    { 32,0x38},
    { 33,0x6C},
    { 34,0x56},
    { 35,0x00},
    { 36,0x38},
    { 37,0x6C},
    { 38,0x51},
    { 39,0x00},
    { 40,0x38},
    { 41,0x68},
    { 42,0x52},
    { 43,0x00},
    { 44,0xF8},
    { 45,0x68},
    { 46,0x55},
    { 47,0x00},
    { 48,0x30},
    { 49,0x68},
    { 50,0x03},
    { 51,0x00},
    { 52,0xF0},
    { 53,0x68},
    { 54,0x06},
    { 55,0x00},
    { 56,0x20},
    { 57,0x00},
    { 58,0x5B},
    { 59,0x00},
    { 60,0x38},
    { 61,0x6C},
    { 62,0x07},
    { 63,0x00},
    { 64,0x38},
    { 65,0x6C},
    { 66,0x02},
    { 67,0x00},
    { 68,0x38},
    { 69,0x70},
    { 70,0x01},
    { 71,0x00},
    { 72,0x38},
    { 73,0x70},
    { 74,0x08},
    { 75,0x00},
    { 76,0x38},
    { 77,0x74},
    { 78,0x00},
    { 79,0x00},
    { 80,0x38},
    { 81,0x74},
    { 82,0x09},
    { 83,0x00},
    { 84,0x38},
    { 85,0x78},
    { 86,0x05},
    { 87,0x00},
    { 88,0x30},
    { 89,0x7C},
    { 90,0x78},
    { 91,0x00},
    { 92,0x38},
    { 93,0x7C},
    { 94,0x79},
    { 95,0x00},
    { 96,0x20},
    { 97,0x00},
    { 98,0x0C},
    { 99,0x00},
    {100,0x38},
    {101,0x80},
    {102,0x5D},
    {103,0x00},
    {104,0x38},
    {105,0x80},
    {106,0x94},
    {107,0x00},
    {108,0x38},
    {109,0x84},
    {110,0x7B},
    {111,0x00},
    {112,0x38},
    {113,0x84},
    {114,0x76},
    {115,0x00},
    {116,0x38},
    {117,0x88},
    {118,0x7D},
    {119,0x00},
    {120,0x38},
    {121,0x88},
    {122,0x74},
    {123,0x00},
    {124,0x38},
    {125,0x8C},
    {126,0x83},
    {127,0x00},
    {  0,0x58},
    {  8,0x38},
    {  9,0x8C},
    { 10,0x6E},
    { 11,0x00},
    { 12,0x38},
    { 13,0x90},
    { 14,0x60},
    { 15,0x00},
    { 16,0x38},
    { 17,0x90},
    { 18,0x91},
    { 19,0x00},
    { 20,0x38},
    { 21,0x94},
    { 22,0x5E},
    { 23,0x00},
    { 24,0x38},
    { 25,0x94},
    { 26,0x93},
    { 27,0x00},
    { 28,0x38},
    { 29,0x98},
    { 30,0x84},
    { 31,0x00},
    { 32,0x38},
    { 33,0x98},
    { 34,0x6D},
    { 35,0x00},
    { 36,0x38},
    { 37,0x9C},
    { 38,0x7F},
    { 39,0x00},
    { 40,0x38},
    { 41,0x9C},
    { 42,0x72},
    { 43,0x00},
    { 44,0x38},
    { 45,0xA0},
    { 46,0x62},
    { 47,0x00},
    { 48,0x38},
    { 49,0xA0},
    { 50,0x8F},
    { 51,0x00},
    { 52,0x38},
    { 53,0xA4},
    { 54,0x81},
    { 55,0x00},
    { 56,0x38},
    { 57,0xA4},
    { 58,0x70},
    { 59,0x00},
    { 60,0x38},
    { 61,0xA8},
    { 62,0x66},
    { 63,0x00},
    { 64,0x38},
    { 65,0xA8},
    { 66,0x8B},
    { 67,0x00},
    { 68,0x38},
    { 69,0xAC},
    { 70,0x86},
    { 71,0x00},
    { 72,0x38},
    { 73,0xAC},
    { 74,0x6B},
    { 75,0x00},
    { 76,0x38},
    { 77,0xB0},
    { 78,0x64},
    { 79,0x00},
    { 80,0x38},
    { 81,0xB0},
    { 82,0x8D},
    { 83,0x00},
    { 84,0x38},
    { 85,0xB4},
    { 86,0x68},
    { 87,0x00},
    { 88,0x38},
    { 89,0xB4},
    { 90,0x89},
    { 91,0x00},
    { 92,0x38},
    { 93,0xB8},
    { 94,0x65},
    { 95,0x00},
    { 96,0x38},
    { 97,0xB8},
    { 98,0x8C},
    { 99,0x00},
    {100,0x38},
    {101,0xBC},
    {102,0x7C},
    {103,0x00},
    {104,0x38},
    {105,0xBC},
    {106,0x75},
    {107,0x00},
    {108,0x38},
    {109,0xC0},
    {110,0x61},
    {111,0x00},
    {112,0x38},
    {113,0xC0},
    {114,0x90},
    {115,0x00},
    {116,0x38},
    {117,0xC4},
    {118,0x87},
    {119,0x00},
    {120,0x38},
    {121,0xC4},
    {122,0x6A},
    {123,0x00},
    {124,0x38},
    {125,0xC8},
    {126,0x80},
    {127,0x00},
    {  0,0x59},
    {  8,0x38},
    {  9,0xC8},
    { 10,0x71},
    { 11,0x00},
    { 12,0x38},
    { 13,0xCC},
    { 14,0x82},
    { 15,0x00},
    { 16,0x38},
    { 17,0xCC},
    { 18,0x6F},
    { 19,0x00},
    { 20,0x38},
    { 21,0xD0},
    { 22,0x7E},
    { 23,0x00},
    { 24,0x38},
    { 25,0xD0},
    { 26,0x73},
    { 27,0x00},
    { 28,0x38},
    { 29,0xD4},
    { 30,0x5F},
    { 31,0x00},
    { 32,0x38},
    { 33,0xD4},
    { 34,0x92},
    { 35,0x00},
    { 36,0x38},
    { 37,0xD8},
    { 38,0x7A},
    { 39,0x00},
    { 40,0x38},
    { 41,0xD8},
    { 42,0x77},
    { 43,0x00},
    { 44,0x38},
    { 45,0xDC},
    { 46,0x5C},
    { 47,0x00},
    { 48,0x38},
    { 49,0xDC},
    { 50,0x95},
    { 51,0x00},
    { 52,0x38},
    { 53,0xE0},
    { 54,0x63},
    { 55,0x00},
    { 56,0x38},
    { 57,0xE0},
    { 58,0x8E},
    { 59,0x00},
    { 60,0x38},
    { 61,0xE4},
    { 62,0x69},
    { 63,0x00},
    { 64,0x38},
    { 65,0xE4},
    { 66,0x88},
    { 67,0x00},
    { 68,0x38},
    { 69,0xE8},
    { 70,0x67},
    { 71,0x00},
    { 72,0x38},
    { 73,0xE8},
    { 74,0x8A},
    { 75,0x00},
    { 76,0x38},
    { 77,0xEC},
    { 78,0x85},
    { 79,0x00},
    { 80,0x38},
    { 81,0xEC},
    { 82,0x6C},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x50},
    { 89,0x0C},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x50},
    { 97,0x08},
    { 98,0x00},
    { 99,0x00},
    {100,0x30},
    {101,0x4C},
    {102,0x96},
    {103,0x00},
    {104,0x38},
    {105,0x50},
    {106,0x98},
    {107,0x00},
    {108,0x98},
    {109,0x48},
    {110,0x95},
    {111,0x00},
    {112,0x60},
    {113,0x40},
    {114,0x98},
    {115,0x00},
    {116,0x38},
    {117,0x44},
    {118,0x9A},
    {119,0x00},
    {120,0x28},
    {121,0x00},
    {122,0x97},
    {123,0x00},
    {124,0x68},
    {125,0x40},
    {126,0x97},
    {127,0x00},
    {  0,0x5A},
    {  8,0x58},
    {  9,0x14},
    { 10,0x97},
    { 11,0x00},
    { 12,0x18},
    { 13,0x0C},
    { 14,0x00},
    { 15,0x00},
    { 16,0x28},
    { 17,0x00},
    { 18,0x99},
    { 19,0x00},
    { 20,0x58},
    { 21,0x10},
    { 22,0x48},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x20},
    { 29,0xFC},
    { 30,0x9C},
    { 31,0x00},
    { 32,0x20},
    { 33,0xFC},
    { 34,0x4D},
    { 35,0x00},
    { 36,0x31},
    { 37,0x7B},
    { 38,0xFB},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x38},
    { 45,0x57},
    { 46,0xFB},
    { 47,0x00},
    { 48,0x88},
    { 49,0x17},
    { 50,0xFE},
    { 51,0x00},
    { 52,0x08},
    { 53,0x00},
    { 54,0x03},
    { 55,0x00},
    { 56,0x08},
    { 57,0x04},
    { 58,0x52},
    { 59,0x00},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x88},
    { 65,0x03},
    { 66,0xFF},
    { 67,0x00},
};
#define miniDSP_A_reg_values_COEFF_START   0
#define miniDSP_A_reg_values_COEFF_SIZE    768
#define miniDSP_A_reg_values_INST_START    768
#define miniDSP_A_reg_values_INST_SIZE     1271

reg_value miniDSP_D_reg_values[] = {
    {  0,0x2C},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x7F},
    { 21,0xFF},
    { 22,0xFF},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    {  0,0x3E},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x7F},
    { 21,0xFF},
    { 22,0xFF},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    {  0,0x98},
    {  8,0x88},
    {  9,0x03},
    { 10,0xFF},
    { 11,0x00},
};
#define miniDSP_D_reg_values_COEFF_START   0
#define miniDSP_D_reg_values_COEFF_SIZE    42
#define miniDSP_D_reg_values_INST_START    42
#define miniDSP_D_reg_values_INST_SIZE     5
