//CONTROL LOCATIONS
typedef struct {
            u8 control_page;           //coefficient page location
            u8 control_base;           //coefficient base address within page
            u8 control_mute_flag;      //non-zero means muting required
            u8 control_string_index;   //string table index
} control; 


static control MUX_controls[] = {
};

static string MUX_control_names[] = {
};

static control VOLUME_controls[] = {
};

static string VOLUME_control_names[] = {
};

//INSTRUCTIONS & COEFFICIENTS
typedef struct {
    u8 reg_off;
    u8 reg_val;
} reg_value;

static string REG_Section_names[] = {
    "miniDSP_A_reg_values",
    "miniDSP_D_reg_values",
};

reg_value REG_Section_program[] = {
    {  0,0x00},
//			# reg[  0][  1] = 0x01	; Initialize the device through software reset
    {  1,0x01},
    {254,0x0A},
    {  0,0x01},
//			# reg[  1][  1] = 0x08	; Power up AVDD LDO; Disable weak AVDD to DVDD connection; Enable Master Analog Power Control, AVDD LDO Powered; Disable weak AVDD to DVDD connection
    {  1,0x08},
//			# reg[  1][  2] = 0x00	; Enable Master Analog Power Control
    {  2,0x00},
//			# reg[  1][ 71] = 0x32	; Set the input power-up time to 3.1ms
    { 71,0x32},
//			# reg[  1][123] = 0x01	; Set REF charging time to 40ms (automatic)
    {123,0x01},
    {255,0x00},
    {255,0x01},
    {  0,0x00},
//			# reg[  0][ 60] = 0x00    ; DAC prog Mode: miniDSP_A and miniDSP_D NOT powered up together, miniDSP_A used for signal processing
    { 60,0x00},
//			# reg[  0][ 61] = 0x00	; Use miniDSP_A for signal processing
    { 61,0x00},
//			# reg[  0][ 17] = 0x08	; 8x Interpolation
    { 17,0x08},
//			# reg[  0][ 23] = 0x04	; 4x Decimation
    { 23,0x04},
//			
    { 15,0x03},
//			
    { 16,0x88},
//			
    { 21,0x03},
//			
    { 22,0x88},
    {  0,0x08},
//			# reg[  8][  1] = 0x04	; adaptive mode for ADC
    {  1,0x04},
    {  0,0x2C},
//			# reg[ 44][  1] = 0x04	; adaptive mode for DAC
    {  1,0x04},
    {  0,0x00},
//			# reg[  0][  5] = 0x91	; P=1, R=1, J=8
    {  5,0x91},
//			# reg[  0][  6] = 0x08	; P=1, R=1, J=8
    {  6,0x08},
//			# reg[  0][  7] = 0x00	; D=0000 (MSB)
    {  7,0x00},
//			# reg[  0][  8] = 0x00	; D=0000 (LSB)
    {  8,0x00},
//			# reg[  0][  4] = 0x03	; PLL_clkin = MCLK, codec_clkin = PLL_CLK, PLL on
    {  4,0x03},
//			# reg[  0][ 12] = 0x88	; MDAC = 8, divider powered on
    { 12,0x88},
//			# reg[  0][ 13] = 0x00	; DOSR = 128 (MSB)
    { 13,0x00},
//			# reg[  0][ 14] = 0x80	; DOSR = 128 (LSB)
    { 14,0x80},
//			# reg[  0][ 18] = 0x02	; NADC = 2, divider powered off
    { 18,0x02},
//			# reg[  0][ 19] = 0x88	; MADC = 8, divider powered on
    { 19,0x88},
//			# reg[  0][ 20] = 0x80	; AOSR = 128
    { 20,0x80},
//			# reg[  0][ 11] = 0x82	; NDAC = 2, divider powered on
    { 11,0x82},
    {  0,0x01},
//			# reg[  1][ 51] = 0x40	; Mic Bias enabled, Source = Avdd, 1.25V
    { 51,0x40},
//			# reg[  1][ 52] = 0x40	; Route IN2L to LEFT_P with 10K input impedance; Route CM1L to LEFT_M with 10K input impedance; Route IN2R to RIGHT_P with 10K input impedance; Route IN1L to LEFT_P with 10K input impedance
    { 52,0x40},
//			# reg[  1][ 54] = 0x40	; Route CM1L to LEFT_M with 10K input impedance
    { 54,0x40},
//			# reg[  1][ 55] = 0x40	; Route IN1R to RIGHT_P with 10K input impedance
    { 55,0x40},
//			# reg[  1][ 57] = 0x40	; Route CM1R to RIGHT_M with 10K input impedance
    { 57,0x40},
//			# reg[  1][ 59] = 0x00	; Enable MicPGA_L Gain Control, 0dB
    { 59,0x00},
//			# reg[  1][ 60] = 0x00	; Enable MicPGA_R Gain Control, 0dB
    { 60,0x00},
    {  0,0x00},
//			# reg[  0][ 81] = 0xc0	; Power up LADC/RADC
    { 81,0xC0},
//			# reg[  0][ 82] = 0x00	; Unmute LADC/RADC
    { 82,0x00},
    {  0,0x01},
//			# reg[  1][ 20] = 0x25	; De-pop: 5 time constants, 6k resistance
    { 20,0x25},
//			# reg[  1][ 12] = 0x08	; Route LDAC to HPL
    { 12,0x08},
//			# reg[  1][ 13] = 0x08	; Route RDAC to HPR
    { 13,0x08},
//			# reg[  1][ 14] = 0x08	; Route LDAC to LOL
    { 14,0x08},
//			# reg[  1][ 15] = 0x08	; Route LDAC to LOR
    { 15,0x08},
    {  0,0x00},
//			# reg[  0][ 63] = 0xd4	; Power up LDAC/RDAC w/ soft stepping
    { 63,0xD4},
    {  0,0x01},
//			# reg[  1][ 16] = 0x00	; Unmute HPL driver, 0dB Gain
    { 16,0x00},
//			# reg[  1][ 17] = 0x00	; Unmute HPR driver, 0dB Gain
    { 17,0x00},
//			# reg[  1][ 18] = 0x00	; Unmute LOL driver, 0dB Gain
    { 18,0x00},
//			# reg[  1][ 19] = 0x00	; Unmute LOR driver, 0dB Gain
    { 19,0x00},
//			# reg[  1][  9] = 0x3c	; Power up HPL/HPR and LOL/LOR drivers
    {  9,0x3C},
    {  0,0x00},
//			# reg[  0][ 64] = 0x00	; Unmute LDAC/RDAC
    { 64,0x00},
//			# reg[0][82] = 0
    { 82,0x00},
//			# reg[0][83] = 0
    { 83,0x00},
//			# reg[0][86] = 0
    { 86,0x00},
//			# reg[0][87] = 254
    { 87,0xFE},
//			# reg[0][88] = 0
    { 88,0x00},
//			# reg[0][89] = 104
    { 89,0x68},
//			# reg[0][90] = 168
    { 90,0xA8},
//			# reg[0][91] = 6
    { 91,0x06},
//			# reg[0][92] = 0
    { 92,0x00},
//			# reg[0][84] = 0
    { 84,0x00},
//			# reg[0][94] = 0
    { 94,0x00},
//			# reg[0][95] = 254
    { 95,0xFE},
//			# reg[0][96] = 0
    { 96,0x00},
//			# reg[0][97] = 104
    { 97,0x68},
//			# reg[0][98] = 168
    { 98,0xA8},
//			# reg[0][99] = 6
    { 99,0x06},
//			# reg[0][100] = 0
    {100,0x00},
};

reg_value miniDSP_A_reg_values[] = {
    {  0,0x08},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x7F},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x26},
    { 49,0x66},
    { 50,0x67},
    { 51,0x00},
    { 52,0x19},
    { 53,0x99},
    { 54,0x9A},
    { 55,0x00},
    { 56,0x00},
    { 57,0x31},
    { 58,0x7F},
    { 59,0x00},
    { 60,0x7F},
    { 61,0xDF},
    { 62,0x3B},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x15},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x04},
    { 71,0x00},
    { 72,0x00},
    { 73,0xCC},
    { 74,0xCC},
    { 75,0x00},
    { 76,0x80},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x78},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x80},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x3F},
    { 89,0xFC},
    { 90,0x94},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFF},
    { 94,0xFF},
    { 95,0x00},
    { 96,0x80},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x7F},
    {101,0xFF},
    {102,0xFF},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0xFF},
    {113,0x9E},
    {114,0x00},
    {115,0x00},
    {116,0xF7},
    {117,0x10},
    {118,0x00},
    {119,0x00},
    {120,0x26},
    {121,0xF0},
    {122,0x00},
    {123,0x00},
    {124,0x02},
    {125,0x61},
    {126,0x00},
    {127,0x00},
    {  0,0x09},
    {  8,0x40},
    {  9,0x02},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xFC},
    { 14,0x00},
    { 15,0x00},
    { 16,0xFF},
    { 17,0xFD},
    { 18,0x00},
    { 19,0x00},
    { 20,0xFF},
    { 21,0xE5},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0xA7},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xC7},
    { 30,0x00},
    { 31,0x00},
    { 32,0xFF},
    { 33,0xCE},
    { 34,0x00},
    { 35,0x00},
    { 36,0xFF},
    { 37,0xFE},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFE},
    { 41,0xF7},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0x46},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x22},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x0F},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFA},
    { 57,0x8C},
    { 58,0x00},
    { 59,0x00},
    { 60,0xF5},
    { 61,0x08},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFD},
    { 65,0x92},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF3},
    { 69,0xA3},
    { 70,0x00},
    { 71,0x00},
    { 72,0x03},
    { 73,0xB3},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x33},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x71},
    { 82,0x00},
    { 83,0x00},
    { 84,0x40},
    { 85,0x60},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0xE2},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0xC6},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x87},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x0F},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x0A},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x81},
    {114,0x00},
    {115,0x00},
    {116,0x18},
    {117,0x89},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xFB},
    {122,0x00},
    {123,0x00},
    {124,0x03},
    {125,0xBE},
    {126,0x00},
    {127,0x00},
    {  0,0x0A},
    {  8,0x00},
    {  9,0x49},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xF2},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF9},
    { 17,0xBA},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0x68},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x2C},
    { 30,0x00},
    { 31,0x00},
    { 32,0xEB},
    { 33,0x8D},
    { 34,0x00},
    { 35,0x00},
    { 36,0x03},
    { 37,0x83},
    { 38,0x00},
    { 39,0x00},
    { 40,0x01},
    { 41,0xC3},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0xD3},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x33},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x02},
    { 54,0x00},
    { 55,0x00},
    { 56,0x32},
    { 57,0x08},
    { 58,0x00},
    { 59,0x00},
    { 60,0x0A},
    { 61,0xFA},
    { 62,0x00},
    { 63,0x00},
    { 64,0x54},
    { 65,0x7B},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x6B},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x03},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFC},
    { 77,0xC6},
    { 78,0x00},
    { 79,0x00},
    { 80,0xF5},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xF9},
    { 85,0x64},
    { 86,0x00},
    { 87,0x00},
    { 88,0x39},
    { 89,0x80},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x1C},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0x2F},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x67},
    {102,0x00},
    {103,0x00},
    {104,0x0F},
    {105,0x73},
    {106,0x00},
    {107,0x00},
    {108,0x2C},
    {109,0x2B},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x80},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x7F},
    {121,0xFF},
    {122,0xFF},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x0B},
    {  8,0x0C},
    {  9,0xCC},
    { 10,0xCD},
    { 11,0x00},
    { 12,0x9B},
    { 13,0x78},
    { 14,0x13},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x36},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0xAE},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x5B},
    { 27,0x00},
    {  0,0x1A},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x7F},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x26},
    { 49,0x66},
    { 50,0x67},
    { 51,0x00},
    { 52,0x19},
    { 53,0x99},
    { 54,0x9A},
    { 55,0x00},
    { 56,0x00},
    { 57,0x31},
    { 58,0x7F},
    { 59,0x00},
    { 60,0x7F},
    { 61,0xDF},
    { 62,0x3B},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x15},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x04},
    { 71,0x00},
    { 72,0x00},
    { 73,0xCC},
    { 74,0xCC},
    { 75,0x00},
    { 76,0x80},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x78},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x80},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x3F},
    { 89,0xFC},
    { 90,0x94},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFF},
    { 94,0xFF},
    { 95,0x00},
    { 96,0x80},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x7F},
    {101,0xFF},
    {102,0xFF},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0xFF},
    {113,0x9E},
    {114,0x00},
    {115,0x00},
    {116,0xF7},
    {117,0x10},
    {118,0x00},
    {119,0x00},
    {120,0x26},
    {121,0xF0},
    {122,0x00},
    {123,0x00},
    {124,0x02},
    {125,0x61},
    {126,0x00},
    {127,0x00},
    {  0,0x1B},
    {  8,0x40},
    {  9,0x02},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xFC},
    { 14,0x00},
    { 15,0x00},
    { 16,0xFF},
    { 17,0xFD},
    { 18,0x00},
    { 19,0x00},
    { 20,0xFF},
    { 21,0xE5},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0xA7},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xC7},
    { 30,0x00},
    { 31,0x00},
    { 32,0xFF},
    { 33,0xCE},
    { 34,0x00},
    { 35,0x00},
    { 36,0xFF},
    { 37,0xFE},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFE},
    { 41,0xF7},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0x46},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x22},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x0F},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFA},
    { 57,0x8C},
    { 58,0x00},
    { 59,0x00},
    { 60,0xF5},
    { 61,0x08},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFD},
    { 65,0x92},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF3},
    { 69,0xA3},
    { 70,0x00},
    { 71,0x00},
    { 72,0x03},
    { 73,0xB3},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x33},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x71},
    { 82,0x00},
    { 83,0x00},
    { 84,0x40},
    { 85,0x60},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0xE2},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0xC6},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x87},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x0F},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x0A},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x02},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x81},
    {114,0x00},
    {115,0x00},
    {116,0x18},
    {117,0x89},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xFB},
    {122,0x00},
    {123,0x00},
    {124,0x03},
    {125,0xBE},
    {126,0x00},
    {127,0x00},
    {  0,0x1C},
    {  8,0x00},
    {  9,0x49},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0xF2},
    { 14,0x00},
    { 15,0x00},
    { 16,0xF9},
    { 17,0xBA},
    { 18,0x00},
    { 19,0x00},
    { 20,0xF9},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFF},
    { 25,0x68},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x2C},
    { 30,0x00},
    { 31,0x00},
    { 32,0xEB},
    { 33,0x8D},
    { 34,0x00},
    { 35,0x00},
    { 36,0x03},
    { 37,0x83},
    { 38,0x00},
    { 39,0x00},
    { 40,0x01},
    { 41,0xC3},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0xD3},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x33},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x02},
    { 54,0x00},
    { 55,0x00},
    { 56,0x32},
    { 57,0x08},
    { 58,0x00},
    { 59,0x00},
    { 60,0x0A},
    { 61,0xFA},
    { 62,0x00},
    { 63,0x00},
    { 64,0x54},
    { 65,0x7B},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x6B},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x03},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFC},
    { 77,0xC6},
    { 78,0x00},
    { 79,0x00},
    { 80,0xF5},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xF9},
    { 85,0x64},
    { 86,0x00},
    { 87,0x00},
    { 88,0x39},
    { 89,0x80},
    { 90,0x00},
    { 91,0x00},
    { 92,0x03},
    { 93,0x1C},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0x2F},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x67},
    {102,0x00},
    {103,0x00},
    {104,0x0F},
    {105,0x73},
    {106,0x00},
    {107,0x00},
    {108,0x2C},
    {109,0x2B},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x80},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x7F},
    {121,0xFF},
    {122,0xFF},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x1D},
    {  8,0x0C},
    {  9,0xCC},
    { 10,0xCD},
    { 11,0x00},
    { 12,0x9B},
    { 13,0x78},
    { 14,0x13},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x36},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0xAE},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x5B},
    { 27,0x00},
    {  0,0x50},
    {  8,0x31},
    {  9,0x58},
    { 10,0x9D},
    { 11,0x00},
    { 12,0x30},
    { 13,0x24},
    { 14,0xA7},
    { 15,0x00},
    { 16,0xD8},
    { 17,0x20},
    { 18,0xA6},
    { 19,0x00},
    { 20,0x20},
    { 21,0x10},
    { 22,0xA2},
    { 23,0x00},
    { 24,0x38},
    { 25,0x1C},
    { 26,0xA4},
    { 27,0x00},
    { 28,0xD8},
    { 29,0x18},
    { 30,0xA3},
    { 31,0x00},
    { 32,0x38},
    { 33,0x14},
    { 34,0xA2},
    { 35,0x00},
    { 36,0x31},
    { 37,0x5C},
    { 38,0xA0},
    { 39,0x00},
    { 40,0x38},
    { 41,0x28},
    { 42,0xA0},
    { 43,0x00},
    { 44,0x20},
    { 45,0x00},
    { 46,0xA5},
    { 47,0x00},
    { 48,0x49},
    { 49,0x5C},
    { 50,0x00},
    { 51,0x00},
    { 52,0x68},
    { 53,0x28},
    { 54,0xA5},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x49},
    { 61,0x6C},
    { 62,0x00},
    { 63,0x00},
    { 64,0x20},
    { 65,0x00},
    { 66,0x9F},
    { 67,0x00},
    { 68,0x38},
    { 69,0x3F},
    { 70,0xFB},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x20},
    { 77,0x04},
    { 78,0x9E},
    { 79,0x00},
    { 80,0x88},
    { 81,0x14},
    { 82,0x35},
    { 83,0x00},
    { 84,0x31},
    { 85,0x60},
    { 86,0x9E},
    { 87,0x00},
    { 88,0x38},
    { 89,0x3B},
    { 90,0xFB},
    { 91,0x00},
    { 92,0x31},
    { 93,0x60},
    { 94,0x9E},
    { 95,0x00},
    { 96,0x38},
    { 97,0x37},
    { 98,0xFB},
    { 99,0x00},
    {100,0x88},
    {101,0x14},
    {102,0x26},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x20},
    {109,0x00},
    {110,0xA1},
    {111,0x00},
    {112,0x61},
    {113,0x5C},
    {114,0xA1},
    {115,0x00},
    {116,0x38},
    {117,0x43},
    {118,0xFB},
    {119,0x00},
    {120,0x31},
    {121,0x5C},
    {122,0xA1},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x51},
    {  8,0x88},
    {  9,0x14},
    { 10,0x24},
    { 11,0x00},
    { 12,0x88},
    { 13,0x18},
    { 14,0x0F},
    { 15,0x00},
    { 16,0x30},
    { 17,0x47},
    { 18,0xFB},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x49},
    { 25,0x64},
    { 26,0x02},
    { 27,0x00},
    { 28,0x38},
    { 29,0x50},
    { 30,0xA9},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x20},
    { 37,0x00},
    { 38,0xA1},
    { 39,0x00},
    { 40,0x88},
    { 41,0x14},
    { 42,0x03},
    { 43,0x00},
    { 44,0x30},
    { 45,0x50},
    { 46,0xA9},
    { 47,0x00},
    { 48,0x30},
    { 49,0x2F},
    { 50,0xFB},
    { 51,0x00},
    { 52,0x88},
    { 53,0x00},
    { 54,0x03},
    { 55,0x00},
    { 56,0x31},
    { 57,0x5C},
    { 58,0xA1},
    { 59,0x00},
    { 60,0x30},
    { 61,0x2F},
    { 62,0xFB},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0x04},
    { 70,0xA8},
    { 71,0x00},
    { 72,0x88},
    { 73,0x00},
    { 74,0x32},
    { 75,0x00},
    { 76,0x30},
    { 77,0x4B},
    { 78,0xFB},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x49},
    { 85,0x64},
    { 86,0x02},
    { 87,0x00},
    { 88,0x38},
    { 89,0x4C},
    { 90,0xA9},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x20},
    { 97,0x00},
    { 98,0xA1},
    { 99,0x00},
    {100,0x88},
    {101,0x18},
    {102,0x03},
    {103,0x00},
    {104,0x30},
    {105,0x4C},
    {106,0xA9},
    {107,0x00},
    {108,0x30},
    {109,0x33},
    {110,0xFB},
    {111,0x00},
    {112,0x88},
    {113,0x00},
    {114,0x03},
    {115,0x00},
    {116,0x31},
    {117,0x5C},
    {118,0xA1},
    {119,0x00},
    {120,0x30},
    {121,0x33},
    {122,0xFB},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x52},
    {  8,0x20},
    {  9,0x04},
    { 10,0xA8},
    { 11,0x00},
    { 12,0x88},
    { 13,0x00},
    { 14,0x23},
    { 15,0x00},
    { 16,0x31},
    { 17,0x64},
    { 18,0xA9},
    { 19,0x00},
    { 20,0x30},
    { 21,0x33},
    { 22,0xFB},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x20},
    { 29,0x04},
    { 30,0xA8},
    { 31,0x00},
    { 32,0x88},
    { 33,0x00},
    { 34,0x0F},
    { 35,0x00},
    { 36,0x31},
    { 37,0x64},
    { 38,0xA9},
    { 39,0x00},
    { 40,0x30},
    { 41,0x33},
    { 42,0xFB},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x20},
    { 49,0x04},
    { 50,0xA8},
    { 51,0x00},
    { 52,0x88},
    { 53,0x00},
    { 54,0x11},
    { 55,0x00},
    { 56,0x31},
    { 57,0x5F},
    { 58,0xFB},
    { 59,0x00},
    { 60,0x30},
    { 61,0x2F},
    { 62,0xFB},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0xF8},
    { 70,0xA8},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x00},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x53},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x41},
    { 37,0x68},
    { 38,0x02},
    { 39,0x00},
    { 40,0x31},
    { 41,0x5C},
    { 42,0xAB},
    { 43,0x00},
    { 44,0x39},
    { 45,0x68},
    { 46,0xAB},
    { 47,0x00},
    { 48,0x39},
    { 49,0x68},
    { 50,0xA8},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x49},
    { 57,0x5C},
    { 58,0x00},
    { 59,0x00},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x20},
    { 69,0x00},
    { 70,0xAA},
    { 71,0x00},
    { 72,0x41},
    { 73,0x58},
    { 74,0x00},
    { 75,0x00},
    { 76,0x31},
    { 77,0x73},
    { 78,0xFB},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x38},
    { 85,0x57},
    { 86,0xFB},
    { 87,0x00},
    { 88,0x88},
    { 89,0x17},
    { 90,0xFE},
    { 91,0x00},
    { 92,0x30},
    { 93,0x78},
    { 94,0x0C},
    { 95,0x00},
    { 96,0x38},
    { 97,0x74},
    { 98,0x07},
    { 99,0x00},
    {100,0x38},
    {101,0x74},
    {102,0x03},
    {103,0x00},
    {104,0x38},
    {105,0x70},
    {106,0x08},
    {107,0x00},
    {108,0x38},
    {109,0x70},
    {110,0x02},
    {111,0x00},
    {112,0x38},
    {113,0x6C},
    {114,0x01},
    {115,0x00},
    {116,0x38},
    {117,0x6C},
    {118,0x09},
    {119,0x00},
    {120,0x38},
    {121,0x68},
    {122,0x0A},
    {123,0x00},
    {124,0xF0},
    {125,0x68},
    {126,0x00},
    {127,0x00},
    {  0,0x54},
    {  8,0x30},
    {  9,0x68},
    { 10,0x59},
    { 11,0x00},
    { 12,0xF8},
    { 13,0x68},
    { 14,0x4F},
    { 15,0x00},
    { 16,0x20},
    { 17,0x00},
    { 18,0x2A},
    { 19,0x00},
    { 20,0x38},
    { 21,0x6C},
    { 22,0x50},
    { 23,0x00},
    { 24,0x38},
    { 25,0x6C},
    { 26,0x58},
    { 27,0x00},
    { 28,0x38},
    { 29,0x70},
    { 30,0x57},
    { 31,0x00},
    { 32,0x38},
    { 33,0x70},
    { 34,0x51},
    { 35,0x00},
    { 36,0x38},
    { 37,0x74},
    { 38,0x56},
    { 39,0x00},
    { 40,0x38},
    { 41,0x74},
    { 42,0x52},
    { 43,0x00},
    { 44,0x38},
    { 45,0x78},
    { 46,0x5B},
    { 47,0x00},
    { 48,0x30},
    { 49,0x7C},
    { 50,0x29},
    { 51,0x00},
    { 52,0x38},
    { 53,0x7C},
    { 54,0x2A},
    { 55,0x00},
    { 56,0x20},
    { 57,0x00},
    { 58,0x79},
    { 59,0x00},
    { 60,0x38},
    { 61,0x80},
    { 62,0x0E},
    { 63,0x00},
    { 64,0x38},
    { 65,0x80},
    { 66,0x45},
    { 67,0x00},
    { 68,0x38},
    { 69,0x84},
    { 70,0x2C},
    { 71,0x00},
    { 72,0x38},
    { 73,0x84},
    { 74,0x27},
    { 75,0x00},
    { 76,0x38},
    { 77,0x88},
    { 78,0x2E},
    { 79,0x00},
    { 80,0x38},
    { 81,0x88},
    { 82,0x25},
    { 83,0x00},
    { 84,0x38},
    { 85,0x8C},
    { 86,0x34},
    { 87,0x00},
    { 88,0x38},
    { 89,0x8C},
    { 90,0x1F},
    { 91,0x00},
    { 92,0x38},
    { 93,0x90},
    { 94,0x11},
    { 95,0x00},
    { 96,0x38},
    { 97,0x90},
    { 98,0x42},
    { 99,0x00},
    {100,0x38},
    {101,0x94},
    {102,0x0F},
    {103,0x00},
    {104,0x38},
    {105,0x94},
    {106,0x44},
    {107,0x00},
    {108,0x38},
    {109,0x98},
    {110,0x35},
    {111,0x00},
    {112,0x38},
    {113,0x98},
    {114,0x1E},
    {115,0x00},
    {116,0x38},
    {117,0x9C},
    {118,0x30},
    {119,0x00},
    {120,0x38},
    {121,0x9C},
    {122,0x23},
    {123,0x00},
    {124,0x38},
    {125,0xA0},
    {126,0x13},
    {127,0x00},
    {  0,0x55},
    {  8,0x38},
    {  9,0xA0},
    { 10,0x40},
    { 11,0x00},
    { 12,0x38},
    { 13,0xA4},
    { 14,0x32},
    { 15,0x00},
    { 16,0x38},
    { 17,0xA4},
    { 18,0x21},
    { 19,0x00},
    { 20,0x38},
    { 21,0xA8},
    { 22,0x17},
    { 23,0x00},
    { 24,0x38},
    { 25,0xA8},
    { 26,0x3C},
    { 27,0x00},
    { 28,0x38},
    { 29,0xAC},
    { 30,0x37},
    { 31,0x00},
    { 32,0x38},
    { 33,0xAC},
    { 34,0x1C},
    { 35,0x00},
    { 36,0x38},
    { 37,0xB0},
    { 38,0x15},
    { 39,0x00},
    { 40,0x38},
    { 41,0xB0},
    { 42,0x3E},
    { 43,0x00},
    { 44,0x38},
    { 45,0xB4},
    { 46,0x19},
    { 47,0x00},
    { 48,0x38},
    { 49,0xB4},
    { 50,0x3A},
    { 51,0x00},
    { 52,0x38},
    { 53,0xB8},
    { 54,0x16},
    { 55,0x00},
    { 56,0x38},
    { 57,0xB8},
    { 58,0x3D},
    { 59,0x00},
    { 60,0x38},
    { 61,0xBC},
    { 62,0x2D},
    { 63,0x00},
    { 64,0x38},
    { 65,0xBC},
    { 66,0x26},
    { 67,0x00},
    { 68,0x38},
    { 69,0xC0},
    { 70,0x12},
    { 71,0x00},
    { 72,0x38},
    { 73,0xC0},
    { 74,0x41},
    { 75,0x00},
    { 76,0x38},
    { 77,0xC4},
    { 78,0x38},
    { 79,0x00},
    { 80,0x38},
    { 81,0xC4},
    { 82,0x1B},
    { 83,0x00},
    { 84,0x38},
    { 85,0xC8},
    { 86,0x31},
    { 87,0x00},
    { 88,0x38},
    { 89,0xC8},
    { 90,0x22},
    { 91,0x00},
    { 92,0x38},
    { 93,0xCC},
    { 94,0x33},
    { 95,0x00},
    { 96,0x38},
    { 97,0xCC},
    { 98,0x20},
    { 99,0x00},
    {100,0x38},
    {101,0xD0},
    {102,0x2F},
    {103,0x00},
    {104,0x38},
    {105,0xD0},
    {106,0x24},
    {107,0x00},
    {108,0x38},
    {109,0xD4},
    {110,0x10},
    {111,0x00},
    {112,0x38},
    {113,0xD4},
    {114,0x43},
    {115,0x00},
    {116,0x38},
    {117,0xD8},
    {118,0x2B},
    {119,0x00},
    {120,0x38},
    {121,0xD8},
    {122,0x28},
    {123,0x00},
    {124,0x38},
    {125,0xDC},
    {126,0x0D},
    {127,0x00},
    {  0,0x56},
    {  8,0x38},
    {  9,0xDC},
    { 10,0x46},
    { 11,0x00},
    { 12,0x38},
    { 13,0xE0},
    { 14,0x14},
    { 15,0x00},
    { 16,0x38},
    { 17,0xE0},
    { 18,0x3F},
    { 19,0x00},
    { 20,0x38},
    { 21,0xE4},
    { 22,0x1A},
    { 23,0x00},
    { 24,0x38},
    { 25,0xE4},
    { 26,0x39},
    { 27,0x00},
    { 28,0x38},
    { 29,0xE8},
    { 30,0x18},
    { 31,0x00},
    { 32,0x38},
    { 33,0xE8},
    { 34,0x3B},
    { 35,0x00},
    { 36,0x38},
    { 37,0xEC},
    { 38,0x36},
    { 39,0x00},
    { 40,0x38},
    { 41,0xEC},
    { 42,0x1D},
    { 43,0x00},
    { 44,0x08},
    { 45,0x00},
    { 46,0x0A},
    { 47,0x00},
    { 48,0x50},
    { 49,0x04},
    { 50,0x00},
    { 51,0x00},
    { 52,0x08},
    { 53,0x04},
    { 54,0x59},
    { 55,0x00},
    { 56,0x50},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x30},
    { 61,0x0C},
    { 62,0x47},
    { 63,0x00},
    { 64,0x38},
    { 65,0x10},
    { 66,0x49},
    { 67,0x00},
    { 68,0x98},
    { 69,0x08},
    { 70,0x46},
    { 71,0x00},
    { 72,0x60},
    { 73,0x00},
    { 74,0x49},
    { 75,0x00},
    { 76,0x38},
    { 77,0x04},
    { 78,0x4B},
    { 79,0x00},
    { 80,0x28},
    { 81,0x00},
    { 82,0x48},
    { 83,0x00},
    { 84,0x68},
    { 85,0x00},
    { 86,0x48},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x18},
    { 93,0x08},
    { 94,0x00},
    { 95,0x00},
    { 96,0x28},
    { 97,0x00},
    { 98,0x4A},
    { 99,0x00},
    {100,0x31},
    {101,0x77},
    {102,0xFB},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x38},
    {109,0x57},
    {110,0xFB},
    {111,0x00},
    {112,0x88},
    {113,0x17},
    {114,0xFE},
    {115,0x00},
    {116,0x30},
    {117,0x78},
    {118,0x54},
    {119,0x00},
    {120,0x38},
    {121,0x74},
    {122,0x4F},
    {123,0x00},
    {124,0x38},
    {125,0x74},
    {126,0x58},
    {127,0x00},
    {  0,0x57},
    {  8,0x38},
    {  9,0x70},
    { 10,0x50},
    { 11,0x00},
    { 12,0x38},
    { 13,0x70},
    { 14,0x57},
    { 15,0x00},
    { 16,0x38},
    { 17,0x6C},
    { 18,0x56},
    { 19,0x00},
    { 20,0x38},
    { 21,0x6C},
    { 22,0x51},
    { 23,0x00},
    { 24,0x38},
    { 25,0x68},
    { 26,0x52},
    { 27,0x00},
    { 28,0xF8},
    { 29,0x68},
    { 30,0x55},
    { 31,0x00},
    { 32,0x30},
    { 33,0x68},
    { 34,0x03},
    { 35,0x00},
    { 36,0xF0},
    { 37,0x68},
    { 38,0x06},
    { 39,0x00},
    { 40,0x20},
    { 41,0x00},
    { 42,0x5B},
    { 43,0x00},
    { 44,0x38},
    { 45,0x6C},
    { 46,0x07},
    { 47,0x00},
    { 48,0x38},
    { 49,0x6C},
    { 50,0x02},
    { 51,0x00},
    { 52,0x38},
    { 53,0x70},
    { 54,0x01},
    { 55,0x00},
    { 56,0x38},
    { 57,0x70},
    { 58,0x08},
    { 59,0x00},
    { 60,0x38},
    { 61,0x74},
    { 62,0x00},
    { 63,0x00},
    { 64,0x38},
    { 65,0x74},
    { 66,0x09},
    { 67,0x00},
    { 68,0x38},
    { 69,0x78},
    { 70,0x05},
    { 71,0x00},
    { 72,0x30},
    { 73,0x7C},
    { 74,0x78},
    { 75,0x00},
    { 76,0x38},
    { 77,0x7C},
    { 78,0x79},
    { 79,0x00},
    { 80,0x20},
    { 81,0x00},
    { 82,0x0C},
    { 83,0x00},
    { 84,0x38},
    { 85,0x80},
    { 86,0x5D},
    { 87,0x00},
    { 88,0x38},
    { 89,0x80},
    { 90,0x94},
    { 91,0x00},
    { 92,0x38},
    { 93,0x84},
    { 94,0x7B},
    { 95,0x00},
    { 96,0x38},
    { 97,0x84},
    { 98,0x76},
    { 99,0x00},
    {100,0x38},
    {101,0x88},
    {102,0x7D},
    {103,0x00},
    {104,0x38},
    {105,0x88},
    {106,0x74},
    {107,0x00},
    {108,0x38},
    {109,0x8C},
    {110,0x83},
    {111,0x00},
    {112,0x38},
    {113,0x8C},
    {114,0x6E},
    {115,0x00},
    {116,0x38},
    {117,0x90},
    {118,0x60},
    {119,0x00},
    {120,0x38},
    {121,0x90},
    {122,0x91},
    {123,0x00},
    {124,0x38},
    {125,0x94},
    {126,0x5E},
    {127,0x00},
    {  0,0x58},
    {  8,0x38},
    {  9,0x94},
    { 10,0x93},
    { 11,0x00},
    { 12,0x38},
    { 13,0x98},
    { 14,0x84},
    { 15,0x00},
    { 16,0x38},
    { 17,0x98},
    { 18,0x6D},
    { 19,0x00},
    { 20,0x38},
    { 21,0x9C},
    { 22,0x7F},
    { 23,0x00},
    { 24,0x38},
    { 25,0x9C},
    { 26,0x72},
    { 27,0x00},
    { 28,0x38},
    { 29,0xA0},
    { 30,0x62},
    { 31,0x00},
    { 32,0x38},
    { 33,0xA0},
    { 34,0x8F},
    { 35,0x00},
    { 36,0x38},
    { 37,0xA4},
    { 38,0x81},
    { 39,0x00},
    { 40,0x38},
    { 41,0xA4},
    { 42,0x70},
    { 43,0x00},
    { 44,0x38},
    { 45,0xA8},
    { 46,0x66},
    { 47,0x00},
    { 48,0x38},
    { 49,0xA8},
    { 50,0x8B},
    { 51,0x00},
    { 52,0x38},
    { 53,0xAC},
    { 54,0x86},
    { 55,0x00},
    { 56,0x38},
    { 57,0xAC},
    { 58,0x6B},
    { 59,0x00},
    { 60,0x38},
    { 61,0xB0},
    { 62,0x64},
    { 63,0x00},
    { 64,0x38},
    { 65,0xB0},
    { 66,0x8D},
    { 67,0x00},
    { 68,0x38},
    { 69,0xB4},
    { 70,0x68},
    { 71,0x00},
    { 72,0x38},
    { 73,0xB4},
    { 74,0x89},
    { 75,0x00},
    { 76,0x38},
    { 77,0xB8},
    { 78,0x65},
    { 79,0x00},
    { 80,0x38},
    { 81,0xB8},
    { 82,0x8C},
    { 83,0x00},
    { 84,0x38},
    { 85,0xBC},
    { 86,0x7C},
    { 87,0x00},
    { 88,0x38},
    { 89,0xBC},
    { 90,0x75},
    { 91,0x00},
    { 92,0x38},
    { 93,0xC0},
    { 94,0x61},
    { 95,0x00},
    { 96,0x38},
    { 97,0xC0},
    { 98,0x90},
    { 99,0x00},
    {100,0x38},
    {101,0xC4},
    {102,0x87},
    {103,0x00},
    {104,0x38},
    {105,0xC4},
    {106,0x6A},
    {107,0x00},
    {108,0x38},
    {109,0xC8},
    {110,0x80},
    {111,0x00},
    {112,0x38},
    {113,0xC8},
    {114,0x71},
    {115,0x00},
    {116,0x38},
    {117,0xCC},
    {118,0x82},
    {119,0x00},
    {120,0x38},
    {121,0xCC},
    {122,0x6F},
    {123,0x00},
    {124,0x38},
    {125,0xD0},
    {126,0x7E},
    {127,0x00},
    {  0,0x59},
    {  8,0x38},
    {  9,0xD0},
    { 10,0x73},
    { 11,0x00},
    { 12,0x38},
    { 13,0xD4},
    { 14,0x5F},
    { 15,0x00},
    { 16,0x38},
    { 17,0xD4},
    { 18,0x92},
    { 19,0x00},
    { 20,0x38},
    { 21,0xD8},
    { 22,0x7A},
    { 23,0x00},
    { 24,0x38},
    { 25,0xD8},
    { 26,0x77},
    { 27,0x00},
    { 28,0x38},
    { 29,0xDC},
    { 30,0x5C},
    { 31,0x00},
    { 32,0x38},
    { 33,0xDC},
    { 34,0x95},
    { 35,0x00},
    { 36,0x38},
    { 37,0xE0},
    { 38,0x63},
    { 39,0x00},
    { 40,0x38},
    { 41,0xE0},
    { 42,0x8E},
    { 43,0x00},
    { 44,0x38},
    { 45,0xE4},
    { 46,0x69},
    { 47,0x00},
    { 48,0x38},
    { 49,0xE4},
    { 50,0x88},
    { 51,0x00},
    { 52,0x38},
    { 53,0xE8},
    { 54,0x67},
    { 55,0x00},
    { 56,0x38},
    { 57,0xE8},
    { 58,0x8A},
    { 59,0x00},
    { 60,0x38},
    { 61,0xEC},
    { 62,0x85},
    { 63,0x00},
    { 64,0x38},
    { 65,0xEC},
    { 66,0x6C},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x50},
    { 73,0x0C},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x50},
    { 81,0x08},
    { 82,0x00},
    { 83,0x00},
    { 84,0x30},
    { 85,0x0C},
    { 86,0x96},
    { 87,0x00},
    { 88,0x38},
    { 89,0x10},
    { 90,0x98},
    { 91,0x00},
    { 92,0x98},
    { 93,0x08},
    { 94,0x95},
    { 95,0x00},
    { 96,0x60},
    { 97,0x00},
    { 98,0x98},
    { 99,0x00},
    {100,0x38},
    {101,0x04},
    {102,0x9A},
    {103,0x00},
    {104,0x28},
    {105,0x00},
    {106,0x97},
    {107,0x00},
    {108,0x68},
    {109,0x00},
    {110,0x97},
    {111,0x00},
    {112,0x58},
    {113,0x14},
    {114,0x97},
    {115,0x00},
    {116,0x18},
    {117,0x0C},
    {118,0x00},
    {119,0x00},
    {120,0x28},
    {121,0x00},
    {122,0x99},
    {123,0x00},
    {124,0x58},
    {125,0x10},
    {126,0x48},
    {127,0x00},
    {  0,0x5A},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x20},
    { 13,0xFC},
    { 14,0x9C},
    { 15,0x00},
    { 16,0x20},
    { 17,0xFC},
    { 18,0x4D},
    { 19,0x00},
    { 20,0x31},
    { 21,0x7B},
    { 22,0xFB},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x38},
    { 29,0x57},
    { 30,0xFB},
    { 31,0x00},
    { 32,0x88},
    { 33,0x17},
    { 34,0xFE},
    { 35,0x00},
    { 36,0x10},
    { 37,0x10},
    { 38,0x4E},
    { 39,0x00},
    { 40,0x10},
    { 41,0x14},
    { 42,0xA2},
    { 43,0x00},
    { 44,0x08},
    { 45,0x00},
    { 46,0x03},
    { 47,0x00},
    { 48,0x08},
    { 49,0x04},
    { 50,0x52},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x88},
    { 57,0x03},
    { 58,0xFF},
    { 59,0x00},
};
#define miniDSP_A_reg_values_COEFF_START   0
#define miniDSP_A_reg_values_COEFF_SIZE    768
#define miniDSP_A_reg_values_INST_START    768
#define miniDSP_A_reg_values_INST_SIZE     1263

reg_value miniDSP_D_reg_values[] = {
    {  0,0x2C},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xF7},
    { 18,0x00},
    { 19,0x00},
    { 20,0x80},
    { 21,0x09},
    { 22,0x00},
    { 23,0x00},
    { 24,0x7F},
    { 25,0xEF},
    { 26,0x00},
    { 27,0x00},
    { 28,0x40},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x7F},
    { 33,0xFF},
    { 34,0xFF},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFF},
    { 41,0xDC},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0xC0},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x0A},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x7B},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFD},
    { 57,0x21},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFE},
    { 61,0x54},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFA},
    { 65,0xBE},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF2},
    { 69,0xAB},
    { 70,0x00},
    { 71,0x00},
    { 72,0x28},
    { 73,0xA9},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x29},
    { 78,0x00},
    { 79,0x00},
    { 80,0x02},
    { 81,0x30},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0xB7},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x5E},
    { 90,0x00},
    { 91,0x00},
    { 92,0x01},
    { 93,0x47},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0xD3},
    { 98,0x00},
    { 99,0x00},
    {100,0x07},
    {101,0xBD},
    {102,0x00},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x14},
    {109,0xEF},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0xEF},
    {114,0x00},
    {115,0x00},
    {116,0x01},
    {117,0x86},
    {118,0x00},
    {119,0x00},
    {120,0x2B},
    {121,0xE8},
    {122,0x00},
    {123,0x00},
    {124,0xFE},
    {125,0x88},
    {126,0x00},
    {127,0x00},
    {  0,0x2D},
    {  8,0xFE},
    {  9,0x15},
    { 10,0x00},
    { 11,0x00},
    { 12,0xF8},
    { 13,0xF9},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x52},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x52},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0xBC},
    { 27,0x00},
    {  0,0x3E},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xF7},
    { 18,0x00},
    { 19,0x00},
    { 20,0x80},
    { 21,0x09},
    { 22,0x00},
    { 23,0x00},
    { 24,0x7F},
    { 25,0xEF},
    { 26,0x00},
    { 27,0x00},
    { 28,0x40},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x7F},
    { 33,0xFF},
    { 34,0xFF},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFF},
    { 41,0xDC},
    { 42,0x00},
    { 43,0x00},
    { 44,0xFF},
    { 45,0xC0},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x0A},
    { 50,0x00},
    { 51,0x00},
    { 52,0xFF},
    { 53,0x7B},
    { 54,0x00},
    { 55,0x00},
    { 56,0xFD},
    { 57,0x21},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFE},
    { 61,0x54},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFA},
    { 65,0xBE},
    { 66,0x00},
    { 67,0x00},
    { 68,0xF2},
    { 69,0xAB},
    { 70,0x00},
    { 71,0x00},
    { 72,0x28},
    { 73,0xA9},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x29},
    { 78,0x00},
    { 79,0x00},
    { 80,0x02},
    { 81,0x30},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0xB7},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x5E},
    { 90,0x00},
    { 91,0x00},
    { 92,0x01},
    { 93,0x47},
    { 94,0x00},
    { 95,0x00},
    { 96,0x03},
    { 97,0xD3},
    { 98,0x00},
    { 99,0x00},
    {100,0x07},
    {101,0xBD},
    {102,0x00},
    {103,0x00},
    {104,0x40},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x14},
    {109,0xEF},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0xEF},
    {114,0x00},
    {115,0x00},
    {116,0x01},
    {117,0x86},
    {118,0x00},
    {119,0x00},
    {120,0x2B},
    {121,0xE8},
    {122,0x00},
    {123,0x00},
    {124,0xFE},
    {125,0x88},
    {126,0x00},
    {127,0x00},
    {  0,0x3F},
    {  8,0xFE},
    {  9,0x15},
    { 10,0x00},
    { 11,0x00},
    { 12,0xF8},
    { 13,0xF9},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x52},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x52},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0xBC},
    { 27,0x00},
    {  0,0x98},
    {  8,0x08},
    {  9,0x08},
    { 10,0x00},
    { 11,0x00},
    { 12,0x08},
    { 13,0x0C},
    { 14,0x01},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x30},
    { 25,0x0C},
    { 26,0x33},
    { 27,0x00},
    { 28,0x38},
    { 29,0x10},
    { 30,0x37},
    { 31,0x00},
    { 32,0x38},
    { 33,0x08},
    { 34,0x32},
    { 35,0x00},
    { 36,0x30},
    { 37,0x0C},
    { 38,0x04},
    { 39,0x00},
    { 40,0x38},
    { 41,0x10},
    { 42,0x08},
    { 43,0x00},
    { 44,0x28},
    { 45,0x00},
    { 46,0x36},
    { 47,0x00},
    { 48,0x38},
    { 49,0x08},
    { 50,0x03},
    { 51,0x00},
    { 52,0x10},
    { 53,0x00},
    { 54,0x2E},
    { 55,0x00},
    { 56,0x30},
    { 57,0x20},
    { 58,0x26},
    { 59,0x00},
    { 60,0xA0},
    { 61,0x20},
    { 62,0x07},
    { 63,0x00},
    { 64,0x10},
    { 65,0x04},
    { 66,0x5D},
    { 67,0x00},
    { 68,0x38},
    { 69,0x24},
    { 70,0x24},
    { 71,0x00},
    { 72,0x38},
    { 73,0x24},
    { 74,0x09},
    { 75,0x00},
    { 76,0x38},
    { 77,0x28},
    { 78,0x20},
    { 79,0x00},
    { 80,0x38},
    { 81,0x28},
    { 82,0x0D},
    { 83,0x00},
    { 84,0x38},
    { 85,0x2C},
    { 86,0x22},
    { 87,0x00},
    { 88,0x38},
    { 89,0x2C},
    { 90,0x0B},
    { 91,0x00},
    { 92,0x38},
    { 93,0x30},
    { 94,0x1C},
    { 95,0x00},
    { 96,0x38},
    { 97,0x30},
    { 98,0x11},
    { 99,0x00},
    {100,0x38},
    {101,0x34},
    {102,0x1E},
    {103,0x00},
    {104,0x38},
    {105,0x34},
    {106,0x0F},
    {107,0x00},
    {108,0x38},
    {109,0x38},
    {110,0x1A},
    {111,0x00},
    {112,0x38},
    {113,0x38},
    {114,0x13},
    {115,0x00},
    {116,0x38},
    {117,0x3C},
    {118,0x18},
    {119,0x00},
    {120,0x38},
    {121,0x3C},
    {122,0x15},
    {123,0x00},
    {124,0x38},
    {125,0x40},
    {126,0x17},
    {127,0x00},
    {  0,0x99},
    {  8,0x38},
    {  9,0x40},
    { 10,0x16},
    { 11,0x00},
    { 12,0x38},
    { 13,0x44},
    { 14,0x25},
    { 15,0x00},
    { 16,0x38},
    { 17,0x44},
    { 18,0x08},
    { 19,0x00},
    { 20,0x38},
    { 21,0x48},
    { 22,0x1D},
    { 23,0x00},
    { 24,0x38},
    { 25,0x48},
    { 26,0x10},
    { 27,0x00},
    { 28,0x38},
    { 29,0x4C},
    { 30,0x21},
    { 31,0x00},
    { 32,0x38},
    { 33,0x4C},
    { 34,0x0C},
    { 35,0x00},
    { 36,0x38},
    { 37,0x50},
    { 38,0x23},
    { 39,0x00},
    { 40,0x38},
    { 41,0x50},
    { 42,0x0A},
    { 43,0x00},
    { 44,0x38},
    { 45,0x54},
    { 46,0x1F},
    { 47,0x00},
    { 48,0x38},
    { 49,0x54},
    { 50,0x0E},
    { 51,0x00},
    { 52,0x38},
    { 53,0x58},
    { 54,0x1B},
    { 55,0x00},
    { 56,0x38},
    { 57,0x58},
    { 58,0x12},
    { 59,0x00},
    { 60,0x38},
    { 61,0x5C},
    { 62,0x19},
    { 63,0x00},
    { 64,0x38},
    { 65,0x5C},
    { 66,0x14},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x30},
    { 73,0x20},
    { 74,0x55},
    { 75,0x00},
    { 76,0x20},
    { 77,0x00},
    { 78,0x2A},
    { 79,0x00},
    { 80,0x38},
    { 81,0x20},
    { 82,0x36},
    { 83,0x00},
    { 84,0x38},
    { 85,0x24},
    { 86,0x53},
    { 87,0x00},
    { 88,0x38},
    { 89,0x24},
    { 90,0x38},
    { 91,0x00},
    { 92,0x38},
    { 93,0x28},
    { 94,0x4F},
    { 95,0x00},
    { 96,0x38},
    { 97,0x28},
    { 98,0x3C},
    { 99,0x00},
    {100,0x38},
    {101,0x2C},
    {102,0x51},
    {103,0x00},
    {104,0x38},
    {105,0x2C},
    {106,0x3A},
    {107,0x00},
    {108,0x38},
    {109,0x30},
    {110,0x4B},
    {111,0x00},
    {112,0x38},
    {113,0x30},
    {114,0x40},
    {115,0x00},
    {116,0x38},
    {117,0x34},
    {118,0x4D},
    {119,0x00},
    {120,0x38},
    {121,0x34},
    {122,0x3E},
    {123,0x00},
    {124,0x38},
    {125,0x38},
    {126,0x49},
    {127,0x00},
    {  0,0x9A},
    {  8,0x38},
    {  9,0x38},
    { 10,0x42},
    { 11,0x00},
    { 12,0x38},
    { 13,0x3C},
    { 14,0x47},
    { 15,0x00},
    { 16,0x38},
    { 17,0x3C},
    { 18,0x44},
    { 19,0x00},
    { 20,0x38},
    { 21,0x40},
    { 22,0x46},
    { 23,0x00},
    { 24,0x38},
    { 25,0x40},
    { 26,0x45},
    { 27,0x00},
    { 28,0x38},
    { 29,0x44},
    { 30,0x54},
    { 31,0x00},
    { 32,0x38},
    { 33,0x44},
    { 34,0x37},
    { 35,0x00},
    { 36,0x38},
    { 37,0x48},
    { 38,0x4C},
    { 39,0x00},
    { 40,0x38},
    { 41,0x48},
    { 42,0x3F},
    { 43,0x00},
    { 44,0x38},
    { 45,0x4C},
    { 46,0x50},
    { 47,0x00},
    { 48,0x38},
    { 49,0x4C},
    { 50,0x3B},
    { 51,0x00},
    { 52,0x38},
    { 53,0x50},
    { 54,0x52},
    { 55,0x00},
    { 56,0x38},
    { 57,0x50},
    { 58,0x39},
    { 59,0x00},
    { 60,0x38},
    { 61,0x54},
    { 62,0x4E},
    { 63,0x00},
    { 64,0x38},
    { 65,0x54},
    { 66,0x3D},
    { 67,0x00},
    { 68,0x38},
    { 69,0x58},
    { 70,0x4A},
    { 71,0x00},
    { 72,0x38},
    { 73,0x58},
    { 74,0x41},
    { 75,0x00},
    { 76,0x38},
    { 77,0x5C},
    { 78,0x48},
    { 79,0x00},
    { 80,0x38},
    { 81,0x5C},
    { 82,0x43},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x30},
    { 89,0x64},
    { 90,0x5B},
    { 91,0x00},
    { 92,0x98},
    { 93,0x68},
    { 94,0x59},
    { 95,0x00},
    { 96,0x38},
    { 97,0x6C},
    { 98,0x5C},
    { 99,0x00},
    {100,0x38},
    {101,0x70},
    {102,0x57},
    {103,0x00},
    {104,0x38},
    {105,0x74},
    {106,0x5A},
    {107,0x00},
    {108,0x38},
    {109,0x78},
    {110,0x56},
    {111,0x00},
    {112,0x38},
    {113,0x7C},
    {114,0x58},
    {115,0x00},
    {116,0x00},
    {117,0x04},
    {118,0x00},
    {119,0x00},
    {120,0x50},
    {121,0x04},
    {122,0x02},
    {123,0x00},
    {124,0x30},
    {125,0x64},
    {126,0x2C},
    {127,0x00},
    {  0,0x9B},
    {  8,0x38},
    {  9,0x68},
    { 10,0x2A},
    { 11,0x00},
    { 12,0x20},
    { 13,0x08},
    { 14,0x5F},
    { 15,0x00},
    { 16,0x38},
    { 17,0x6C},
    { 18,0x2D},
    { 19,0x00},
    { 20,0x38},
    { 21,0x70},
    { 22,0x28},
    { 23,0x00},
    { 24,0x38},
    { 25,0x74},
    { 26,0x2B},
    { 27,0x00},
    { 28,0x38},
    { 29,0x78},
    { 30,0x27},
    { 31,0x00},
    { 32,0x38},
    { 33,0x7C},
    { 34,0x29},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x50},
    { 41,0x00},
    { 42,0x02},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x20},
    { 53,0x08},
    { 54,0x30},
    { 55,0x00},
    { 56,0x30},
    { 57,0x83},
    { 58,0xFB},
    { 59,0x00},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x38},
    { 65,0x03},
    { 66,0xFB},
    { 67,0x00},
    { 68,0x88},
    { 69,0x17},
    { 70,0xFE},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x10},
    { 77,0x00},
    { 78,0x30},
    { 79,0x00},
    { 80,0x10},
    { 81,0x04},
    { 82,0x5F},
    { 83,0x00},
    { 84,0x30},
    { 85,0x64},
    { 86,0x5A},
    { 87,0x00},
    { 88,0x38},
    { 89,0x68},
    { 90,0x5C},
    { 91,0x00},
    { 92,0x38},
    { 93,0x6C},
    { 94,0x59},
    { 95,0x00},
    { 96,0x38},
    { 97,0x70},
    { 98,0x57},
    { 99,0x00},
    {100,0x38},
    {101,0x74},
    {102,0x5B},
    {103,0x00},
    {104,0x38},
    {105,0x78},
    {106,0x58},
    {107,0x00},
    {108,0x38},
    {109,0x7C},
    {110,0x56},
    {111,0x00},
    {112,0x00},
    {113,0x04},
    {114,0x00},
    {115,0x00},
    {116,0x50},
    {117,0x04},
    {118,0x02},
    {119,0x00},
    {120,0x30},
    {121,0x64},
    {122,0x2B},
    {123,0x00},
    {124,0x38},
    {125,0x68},
    {126,0x2D},
    {127,0x00},
    {  0,0x9C},
    {  8,0x20},
    {  9,0x08},
    { 10,0x5E},
    { 11,0x00},
    { 12,0x38},
    { 13,0x6C},
    { 14,0x2A},
    { 15,0x00},
    { 16,0x38},
    { 17,0x70},
    { 18,0x28},
    { 19,0x00},
    { 20,0x38},
    { 21,0x74},
    { 22,0x2C},
    { 23,0x00},
    { 24,0x38},
    { 25,0x78},
    { 26,0x29},
    { 27,0x00},
    { 28,0x38},
    { 29,0x7C},
    { 30,0x27},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x50},
    { 37,0x00},
    { 38,0x02},
    { 39,0x00},
    { 40,0x30},
    { 41,0x60},
    { 42,0x45},
    { 43,0x00},
    { 44,0x30},
    { 45,0x64},
    { 46,0x57},
    { 47,0x00},
    { 48,0x20},
    { 49,0x08},
    { 50,0x2F},
    { 51,0x00},
    { 52,0x98},
    { 53,0x68},
    { 54,0x55},
    { 55,0x00},
    { 56,0x38},
    { 57,0x6C},
    { 58,0x58},
    { 59,0x00},
    { 60,0x38},
    { 61,0x70},
    { 62,0x5A},
    { 63,0x00},
    { 64,0x38},
    { 65,0x74},
    { 66,0x56},
    { 67,0x00},
    { 68,0x38},
    { 69,0x78},
    { 70,0x59},
    { 71,0x00},
    { 72,0x38},
    { 73,0x7C},
    { 74,0x5B},
    { 75,0x00},
    { 76,0x00},
    { 77,0x04},
    { 78,0x00},
    { 79,0x00},
    { 80,0x50},
    { 81,0x04},
    { 82,0x02},
    { 83,0x00},
    { 84,0x30},
    { 85,0x60},
    { 86,0x16},
    { 87,0x00},
    { 88,0x30},
    { 89,0x64},
    { 90,0x28},
    { 91,0x00},
    { 92,0x20},
    { 93,0x08},
    { 94,0x5D},
    { 95,0x00},
    { 96,0x98},
    { 97,0x68},
    { 98,0x26},
    { 99,0x00},
    {100,0x38},
    {101,0x6C},
    {102,0x29},
    {103,0x00},
    {104,0x38},
    {105,0x70},
    {106,0x2B},
    {107,0x00},
    {108,0x38},
    {109,0x74},
    {110,0x27},
    {111,0x00},
    {112,0x38},
    {113,0x78},
    {114,0x2A},
    {115,0x00},
    {116,0x38},
    {117,0x7C},
    {118,0x2C},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x50},
    {125,0x00},
    {126,0x02},
    {127,0x00},
    {  0,0x9D},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x20},
    { 17,0x08},
    { 18,0x2E},
    { 19,0x00},
    { 20,0x30},
    { 21,0x87},
    { 22,0xFB},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x38},
    { 29,0x03},
    { 30,0xFB},
    { 31,0x00},
    { 32,0x88},
    { 33,0x17},
    { 34,0xFE},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x10},
    { 41,0x00},
    { 42,0x2F},
    { 43,0x00},
    { 44,0x10},
    { 45,0x04},
    { 46,0x5E},
    { 47,0x00},
    { 48,0x30},
    { 49,0x64},
    { 50,0x56},
    { 51,0x00},
    { 52,0x38},
    { 53,0x68},
    { 54,0x58},
    { 55,0x00},
    { 56,0x38},
    { 57,0x6C},
    { 58,0x55},
    { 59,0x00},
    { 60,0x38},
    { 61,0x70},
    { 62,0x5A},
    { 63,0x00},
    { 64,0x38},
    { 65,0x74},
    { 66,0x57},
    { 67,0x00},
    { 68,0x38},
    { 69,0x78},
    { 70,0x5B},
    { 71,0x00},
    { 72,0x38},
    { 73,0x7C},
    { 74,0x59},
    { 75,0x00},
    { 76,0x00},
    { 77,0x04},
    { 78,0x00},
    { 79,0x00},
    { 80,0x50},
    { 81,0x04},
    { 82,0x02},
    { 83,0x00},
    { 84,0x30},
    { 85,0x64},
    { 86,0x27},
    { 87,0x00},
    { 88,0x38},
    { 89,0x68},
    { 90,0x29},
    { 91,0x00},
    { 92,0x20},
    { 93,0x08},
    { 94,0x5C},
    { 95,0x00},
    { 96,0x38},
    { 97,0x6C},
    { 98,0x26},
    { 99,0x00},
    {100,0x38},
    {101,0x70},
    {102,0x2B},
    {103,0x00},
    {104,0x38},
    {105,0x74},
    {106,0x28},
    {107,0x00},
    {108,0x38},
    {109,0x78},
    {110,0x2C},
    {111,0x00},
    {112,0x38},
    {113,0x7C},
    {114,0x2A},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x50},
    {121,0x00},
    {122,0x02},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x9E},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x20},
    { 13,0x08},
    { 14,0x2D},
    { 15,0x00},
    { 16,0x30},
    { 17,0x8B},
    { 18,0xFB},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x38},
    { 25,0x03},
    { 26,0xFB},
    { 27,0x00},
    { 28,0x88},
    { 29,0x17},
    { 30,0xFE},
    { 31,0x00},
    { 32,0x30},
    { 33,0x14},
    { 34,0x00},
    { 35,0x00},
    { 36,0x30},
    { 37,0x14},
    { 38,0x01},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x20},
    { 45,0x04},
    { 46,0x02},
    { 47,0x00},
    { 48,0x20},
    { 49,0x04},
    { 50,0x31},
    { 51,0x00},
    { 52,0x10},
    { 53,0x00},
    { 54,0x2E},
    { 55,0x00},
    { 56,0x10},
    { 57,0x04},
    { 58,0x5D},
    { 59,0x00},
    { 60,0x88},
    { 61,0x03},
    { 62,0xFF},
    { 63,0x00},
};
#define miniDSP_D_reg_values_COEFF_START   0
#define miniDSP_D_reg_values_COEFF_SIZE    284
#define miniDSP_D_reg_values_INST_START    284
#define miniDSP_D_reg_values_INST_SIZE     783
