//CONTROL LOCATIONS
typedef struct {
            u8 control_page;           //coefficient page location
            u8 control_base;           //coefficient base address within page
            u8 control_mute_flag;      //non-zero means muting required
            u8 control_string_index;   //string table index
} control; 


static control MUX_controls[] = {
{44,32,1,0}
};

static string MUX_control_names[] = {
"Mono_Mux_1_1"
};

static control VOLUME_controls[] = {
{44,28,0,0}
};

static string VOLUME_control_names[] = {
"Volume_1"
};

//INSTRUCTIONS & COEFFICIENTS
typedef struct {
    u8 reg_off;
    u8 reg_val;
} reg_value;

static string REG_Section_names[] = {
    "miniDSP_A_reg_values",
    "miniDSP_D_reg_values",
};

reg_value REG_Section_program[] = {
    {  0,0x00},
//			# reg[  0][  1] = 0x01	; Initialize the device through software reset
    {  1,0x01},
    {254,0x0A},
    {  0,0x01},
//			# reg[  1][  1] = 0x08	; Power up AVDD LDO; Disable weak AVDD to DVDD connection; Enable Master Analog Power Control, AVDD LDO Powered; Disable weak AVDD to DVDD connection
    {  1,0x08},
//			# reg[  1][  2] = 0x00	; Enable Master Analog Power Control
    {  2,0x00},
//			# reg[  1][ 71] = 0x32	; Set the input power-up time to 3.1ms
    { 71,0x32},
//			# reg[  1][123] = 0x01	; Set REF charging time to 40ms (automatic)
    {123,0x01},
    {255,0x00},
    {255,0x01},
    {  0,0x00},
//			# reg[  0][ 60] = 0x00    ; DAC prog Mode: miniDSP_A and miniDSP_D NOT powered up together, miniDSP_A used for signal processing
    { 60,0x00},
//			# reg[  0][ 61] = 0x00	; Use miniDSP_A for signal processing
    { 61,0x00},
//			# reg[  0][ 17] = 0x08	; 8x Interpolation
    { 17,0x08},
//			# reg[  0][ 23] = 0x04	; 4x Decimation
    { 23,0x04},
//			
    { 15,0x03},
//			
    { 16,0x88},
//			
    { 21,0x03},
//			
    { 22,0x88},
    {  0,0x08},
//			# reg[  8][  1] = 0x04	; adaptive mode for ADC
    {  1,0x04},
    {  0,0x2C},
//			# reg[ 44][  1] = 0x04	; adaptive mode for DAC
    {  1,0x04},
    {  0,0x00},
//			# reg[  0][  5] = 0x91	; P=1, R=1, J=8
    {  5,0x91},
//			# reg[  0][  6] = 0x08	; P=1, R=1, J=8
    {  6,0x08},
//			# reg[  0][  7] = 0x00	; D=0000 (MSB)
    {  7,0x00},
//			# reg[  0][  8] = 0x00	; D=0000 (LSB)
    {  8,0x00},
//			# reg[  0][  4] = 0x03	; PLL_clkin = MCLK, codec_clkin = PLL_CLK, PLL on
    {  4,0x03},
//			# reg[  0][ 12] = 0x88	; MDAC = 8, divider powered on
    { 12,0x88},
//			# reg[  0][ 13] = 0x00	; DOSR = 128 (MSB)
    { 13,0x00},
//			# reg[  0][ 14] = 0x80	; DOSR = 128 (LSB)
    { 14,0x80},
//			# reg[  0][ 18] = 0x02	; NADC = 2, divider powered off
    { 18,0x02},
//			# reg[  0][ 19] = 0x88	; MADC = 8, divider powered on
    { 19,0x88},
//			# reg[  0][ 20] = 0x80	; AOSR = 128
    { 20,0x80},
//			# reg[  0][ 11] = 0x82	; NDAC = 2, divider powered on
    { 11,0x82},
    {  0,0x01},
//			# reg[  1][ 51] = 0x40	; Mic Bias enabled, Source = Avdd, 1.25V
    { 51,0x40},
//			# reg[  1][ 52] = 0x40	; Route IN2L to LEFT_P with 10K input impedance; Route CM1L to LEFT_M with 10K input impedance; Route IN2R to RIGHT_P with 10K input impedance; Route IN1L to LEFT_P with 10K input impedance
    { 52,0x40},
//			# reg[  1][ 54] = 0x40	; Route CM1L to LEFT_M with 10K input impedance
    { 54,0x40},
//			# reg[  1][ 55] = 0x40	; Route IN1R to RIGHT_P with 10K input impedance
    { 55,0x40},
//			# reg[  1][ 57] = 0x40	; Route CM1R to RIGHT_M with 10K input impedance
    { 57,0x40},
//			# reg[  1][ 59] = 0x00	; Enable MicPGA_L Gain Control, 0dB
    { 59,0x00},
//			# reg[  1][ 60] = 0x00	; Enable MicPGA_R Gain Control, 0dB
    { 60,0x00},
    {  0,0x00},
//			# reg[  0][ 81] = 0xc0	; Power up LADC/RADC
    { 81,0xC0},
//			# reg[  0][ 82] = 0x00	; Unmute LADC/RADC
    { 82,0x00},
    {  0,0x01},
//			# reg[  1][ 20] = 0x25	; De-pop: 5 time constants, 6k resistance
    { 20,0x25},
//			# reg[  1][ 12] = 0x08	; Route LDAC to HPL
    { 12,0x08},
//			# reg[  1][ 13] = 0x08	; Route RDAC to HPR
    { 13,0x08},
//			# reg[  1][ 14] = 0x08	; Route LDAC to LOL
    { 14,0x08},
//			# reg[  1][ 15] = 0x08	; Route LDAC to LOR
    { 15,0x08},
    {  0,0x00},
//			# reg[  0][ 63] = 0xd4	; Power up LDAC/RDAC w/ soft stepping
    { 63,0xD4},
    {  0,0x01},
//			# reg[  1][ 16] = 0x00	; Unmute HPL driver, 0dB Gain
    { 16,0x00},
//			# reg[  1][ 17] = 0x00	; Unmute HPR driver, 0dB Gain
    { 17,0x00},
//			# reg[  1][ 18] = 0x00	; Unmute LOL driver, 0dB Gain
    { 18,0x00},
//			# reg[  1][ 19] = 0x00	; Unmute LOR driver, 0dB Gain
    { 19,0x00},
//			# reg[  1][  9] = 0x3c	; Power up HPL/HPR and LOL/LOR drivers
    {  9,0x3C},
    {  0,0x00},
//			# reg[  0][ 64] = 0x00	; Unmute LDAC/RDAC
    { 64,0x00},
//			# reg[0][82] = 0
    { 82,0x00},
//			# reg[0][83] = 0
    { 83,0x00},
//			# reg[0][86] = 32
    { 86,0x20},
//			# reg[0][87] = 254
    { 87,0xFE},
//			# reg[0][88] = 0
    { 88,0x00},
//			# reg[0][89] = 104
    { 89,0x68},
//			# reg[0][90] = 168
    { 90,0xA8},
//			# reg[0][91] = 6
    { 91,0x06},
//			# reg[0][92] = 0
    { 92,0x00},
};

reg_value miniDSP_A_reg_values[] = {
    {  0,0x08},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x80},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x7F},
    { 37,0xFF},
    { 38,0xFF},
    { 39,0x00},
    { 40,0x40},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x9E},
    { 50,0x00},
    { 51,0x00},
    { 52,0xF7},
    { 53,0x10},
    { 54,0x00},
    { 55,0x00},
    { 56,0x26},
    { 57,0xF0},
    { 58,0x00},
    { 59,0x00},
    { 60,0x02},
    { 61,0x61},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x02},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xFC},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0xFD},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFF},
    { 77,0xE5},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0xA7},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFF},
    { 85,0xC7},
    { 86,0x00},
    { 87,0x00},
    { 88,0xFF},
    { 89,0xCE},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFE},
    { 94,0x00},
    { 95,0x00},
    { 96,0xFE},
    { 97,0xF7},
    { 98,0x00},
    { 99,0x00},
    {100,0xFF},
    {101,0x46},
    {102,0x00},
    {103,0x00},
    {104,0xFF},
    {105,0x22},
    {106,0x00},
    {107,0x00},
    {108,0xFF},
    {109,0x0F},
    {110,0x00},
    {111,0x00},
    {112,0xFA},
    {113,0x8C},
    {114,0x00},
    {115,0x00},
    {116,0xF5},
    {117,0x08},
    {118,0x00},
    {119,0x00},
    {120,0xFD},
    {121,0x92},
    {122,0x00},
    {123,0x00},
    {124,0xF3},
    {125,0xA3},
    {126,0x00},
    {127,0x00},
    {  0,0x09},
    {  8,0x03},
    {  9,0xB3},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x33},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x71},
    { 18,0x00},
    { 19,0x00},
    { 20,0x40},
    { 21,0x60},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0xE2},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0xC6},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x87},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x0F},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x0A},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x02},
    { 46,0x00},
    { 47,0x00},
    { 48,0x01},
    { 49,0x81},
    { 50,0x00},
    { 51,0x00},
    { 52,0x18},
    { 53,0x89},
    { 54,0x00},
    { 55,0x00},
    { 56,0x07},
    { 57,0xFB},
    { 58,0x00},
    { 59,0x00},
    { 60,0x03},
    { 61,0xBE},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0xB4},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0xD5},
    { 71,0x00},
    {  0,0x1A},
    {  8,0x00},
    {  9,0xB7},
    { 10,0x98},
    { 11,0x00},
    { 12,0x7E},
    { 13,0x90},
    { 14,0xD0},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFF},
    { 29,0xFF},
    { 30,0xFF},
    { 31,0x00},
    { 32,0x80},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x7F},
    { 37,0xFF},
    { 38,0xFF},
    { 39,0x00},
    { 40,0x40},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0xFF},
    { 49,0x9E},
    { 50,0x00},
    { 51,0x00},
    { 52,0xF7},
    { 53,0x10},
    { 54,0x00},
    { 55,0x00},
    { 56,0x26},
    { 57,0xF0},
    { 58,0x00},
    { 59,0x00},
    { 60,0x02},
    { 61,0x61},
    { 62,0x00},
    { 63,0x00},
    { 64,0x40},
    { 65,0x02},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xFC},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0xFD},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFF},
    { 77,0xE5},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0xA7},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFF},
    { 85,0xC7},
    { 86,0x00},
    { 87,0x00},
    { 88,0xFF},
    { 89,0xCE},
    { 90,0x00},
    { 91,0x00},
    { 92,0xFF},
    { 93,0xFE},
    { 94,0x00},
    { 95,0x00},
    { 96,0xFE},
    { 97,0xF7},
    { 98,0x00},
    { 99,0x00},
    {100,0xFF},
    {101,0x46},
    {102,0x00},
    {103,0x00},
    {104,0xFF},
    {105,0x22},
    {106,0x00},
    {107,0x00},
    {108,0xFF},
    {109,0x0F},
    {110,0x00},
    {111,0x00},
    {112,0xFA},
    {113,0x8C},
    {114,0x00},
    {115,0x00},
    {116,0xF5},
    {117,0x08},
    {118,0x00},
    {119,0x00},
    {120,0xFD},
    {121,0x92},
    {122,0x00},
    {123,0x00},
    {124,0xF3},
    {125,0xA3},
    {126,0x00},
    {127,0x00},
    {  0,0x1B},
    {  8,0x03},
    {  9,0xB3},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x33},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x71},
    { 18,0x00},
    { 19,0x00},
    { 20,0x40},
    { 21,0x60},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0xE2},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0xC6},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x87},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x0F},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x0A},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x02},
    { 46,0x00},
    { 47,0x00},
    { 48,0x01},
    { 49,0x81},
    { 50,0x00},
    { 51,0x00},
    { 52,0x18},
    { 53,0x89},
    { 54,0x00},
    { 55,0x00},
    { 56,0x07},
    { 57,0xFB},
    { 58,0x00},
    { 59,0x00},
    { 60,0x03},
    { 61,0xBE},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0xB4},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0xD5},
    { 71,0x00},
    {  0,0x50},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x30},
    { 17,0x38},
    { 18,0x0C},
    { 19,0x00},
    { 20,0x38},
    { 21,0x34},
    { 22,0x07},
    { 23,0x00},
    { 24,0x38},
    { 25,0x34},
    { 26,0x03},
    { 27,0x00},
    { 28,0x38},
    { 29,0x30},
    { 30,0x08},
    { 31,0x00},
    { 32,0x38},
    { 33,0x30},
    { 34,0x02},
    { 35,0x00},
    { 36,0x38},
    { 37,0x28},
    { 38,0x0A},
    { 39,0x00},
    { 40,0xF0},
    { 41,0x28},
    { 42,0x00},
    { 43,0x00},
    { 44,0x38},
    { 45,0x2C},
    { 46,0x01},
    { 47,0x00},
    { 48,0x38},
    { 49,0x2C},
    { 50,0x09},
    { 51,0x00},
    { 52,0x30},
    { 53,0x3C},
    { 54,0x29},
    { 55,0x00},
    { 56,0x38},
    { 57,0x40},
    { 58,0x0E},
    { 59,0x00},
    { 60,0x98},
    { 61,0x3C},
    { 62,0x2A},
    { 63,0x00},
    { 64,0x38},
    { 65,0x40},
    { 66,0x45},
    { 67,0x00},
    { 68,0x38},
    { 69,0x44},
    { 70,0x2C},
    { 71,0x00},
    { 72,0x38},
    { 73,0x44},
    { 74,0x27},
    { 75,0x00},
    { 76,0x38},
    { 77,0x48},
    { 78,0x2E},
    { 79,0x00},
    { 80,0x38},
    { 81,0x48},
    { 82,0x25},
    { 83,0x00},
    { 84,0x38},
    { 85,0x4C},
    { 86,0x34},
    { 87,0x00},
    { 88,0x38},
    { 89,0x4C},
    { 90,0x1F},
    { 91,0x00},
    { 92,0x38},
    { 93,0x50},
    { 94,0x11},
    { 95,0x00},
    { 96,0x38},
    { 97,0x50},
    { 98,0x42},
    { 99,0x00},
    {100,0x38},
    {101,0x54},
    {102,0x0F},
    {103,0x00},
    {104,0x38},
    {105,0x54},
    {106,0x44},
    {107,0x00},
    {108,0x38},
    {109,0x58},
    {110,0x35},
    {111,0x00},
    {112,0x38},
    {113,0x58},
    {114,0x1E},
    {115,0x00},
    {116,0x38},
    {117,0x5C},
    {118,0x30},
    {119,0x00},
    {120,0x38},
    {121,0x5C},
    {122,0x23},
    {123,0x00},
    {124,0x38},
    {125,0x60},
    {126,0x13},
    {127,0x00},
    {  0,0x51},
    {  8,0x38},
    {  9,0x60},
    { 10,0x40},
    { 11,0x00},
    { 12,0x38},
    { 13,0x64},
    { 14,0x32},
    { 15,0x00},
    { 16,0x38},
    { 17,0x64},
    { 18,0x21},
    { 19,0x00},
    { 20,0x38},
    { 21,0x68},
    { 22,0x17},
    { 23,0x00},
    { 24,0x38},
    { 25,0x68},
    { 26,0x3C},
    { 27,0x00},
    { 28,0x38},
    { 29,0x6C},
    { 30,0x37},
    { 31,0x00},
    { 32,0x38},
    { 33,0x6C},
    { 34,0x1C},
    { 35,0x00},
    { 36,0x38},
    { 37,0x70},
    { 38,0x15},
    { 39,0x00},
    { 40,0x38},
    { 41,0x70},
    { 42,0x3E},
    { 43,0x00},
    { 44,0x38},
    { 45,0x74},
    { 46,0x19},
    { 47,0x00},
    { 48,0x38},
    { 49,0x74},
    { 50,0x3A},
    { 51,0x00},
    { 52,0x38},
    { 53,0x78},
    { 54,0x16},
    { 55,0x00},
    { 56,0x38},
    { 57,0x78},
    { 58,0x3D},
    { 59,0x00},
    { 60,0x38},
    { 61,0x7C},
    { 62,0x2D},
    { 63,0x00},
    { 64,0x38},
    { 65,0x7C},
    { 66,0x26},
    { 67,0x00},
    { 68,0x38},
    { 69,0x80},
    { 70,0x12},
    { 71,0x00},
    { 72,0x38},
    { 73,0x80},
    { 74,0x41},
    { 75,0x00},
    { 76,0x38},
    { 77,0x84},
    { 78,0x38},
    { 79,0x00},
    { 80,0x38},
    { 81,0x84},
    { 82,0x1B},
    { 83,0x00},
    { 84,0x38},
    { 85,0x88},
    { 86,0x31},
    { 87,0x00},
    { 88,0x38},
    { 89,0x88},
    { 90,0x22},
    { 91,0x00},
    { 92,0x38},
    { 93,0x8C},
    { 94,0x33},
    { 95,0x00},
    { 96,0x38},
    { 97,0x8C},
    { 98,0x20},
    { 99,0x00},
    {100,0x38},
    {101,0x90},
    {102,0x2F},
    {103,0x00},
    {104,0x38},
    {105,0x90},
    {106,0x24},
    {107,0x00},
    {108,0x38},
    {109,0x94},
    {110,0x10},
    {111,0x00},
    {112,0x38},
    {113,0x94},
    {114,0x43},
    {115,0x00},
    {116,0x38},
    {117,0x98},
    {118,0x2B},
    {119,0x00},
    {120,0x38},
    {121,0x98},
    {122,0x28},
    {123,0x00},
    {124,0x38},
    {125,0x9C},
    {126,0x0D},
    {127,0x00},
    {  0,0x52},
    {  8,0x38},
    {  9,0x9C},
    { 10,0x46},
    { 11,0x00},
    { 12,0x38},
    { 13,0xA0},
    { 14,0x14},
    { 15,0x00},
    { 16,0x38},
    { 17,0xA0},
    { 18,0x3F},
    { 19,0x00},
    { 20,0x38},
    { 21,0xA4},
    { 22,0x1A},
    { 23,0x00},
    { 24,0x38},
    { 25,0xA4},
    { 26,0x39},
    { 27,0x00},
    { 28,0x38},
    { 29,0xA8},
    { 30,0x18},
    { 31,0x00},
    { 32,0x38},
    { 33,0xA8},
    { 34,0x3B},
    { 35,0x00},
    { 36,0x38},
    { 37,0xAC},
    { 38,0x36},
    { 39,0x00},
    { 40,0x38},
    { 41,0xAC},
    { 42,0x1D},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x50},
    { 49,0x04},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x50},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x30},
    { 61,0x0C},
    { 62,0x47},
    { 63,0x00},
    { 64,0x38},
    { 65,0x10},
    { 66,0x49},
    { 67,0x00},
    { 68,0x98},
    { 69,0x08},
    { 70,0x46},
    { 71,0x00},
    { 72,0x60},
    { 73,0x00},
    { 74,0x49},
    { 75,0x00},
    { 76,0x38},
    { 77,0x04},
    { 78,0x4B},
    { 79,0x00},
    { 80,0x28},
    { 81,0x00},
    { 82,0x48},
    { 83,0x00},
    { 84,0x68},
    { 85,0x00},
    { 86,0x48},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x18},
    { 93,0x08},
    { 94,0x00},
    { 95,0x00},
    { 96,0x28},
    { 97,0x00},
    { 98,0x4A},
    { 99,0x00},
    {100,0x30},
    {101,0xB3},
    {102,0xFB},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x38},
    {109,0x17},
    {110,0xFB},
    {111,0x00},
    {112,0x88},
    {113,0x17},
    {114,0xFE},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x08},
    {121,0x00},
    {122,0x0A},
    {123,0x00},
    {124,0x30},
    {125,0x28},
    {126,0x03},
    {127,0x00},
    {  0,0x53},
    {  8,0xF0},
    {  9,0x28},
    { 10,0x06},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x38},
    { 17,0x2C},
    { 18,0x07},
    { 19,0x00},
    { 20,0x38},
    { 21,0x2C},
    { 22,0x02},
    { 23,0x00},
    { 24,0x38},
    { 25,0x30},
    { 26,0x01},
    { 27,0x00},
    { 28,0x38},
    { 29,0x30},
    { 30,0x08},
    { 31,0x00},
    { 32,0x38},
    { 33,0x34},
    { 34,0x00},
    { 35,0x00},
    { 36,0x38},
    { 37,0x34},
    { 38,0x09},
    { 39,0x00},
    { 40,0x38},
    { 41,0x38},
    { 42,0x05},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x58},
    { 49,0x10},
    { 50,0x48},
    { 51,0x00},
    { 52,0x20},
    { 53,0x00},
    { 54,0x0C},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x20},
    { 61,0xFC},
    { 62,0x4D},
    { 63,0x00},
    { 64,0x30},
    { 65,0xB7},
    { 66,0xFB},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x38},
    { 73,0x17},
    { 74,0xFB},
    { 75,0x00},
    { 76,0x88},
    { 77,0x17},
    { 78,0xFE},
    { 79,0x00},
    { 80,0x10},
    { 81,0x10},
    { 82,0x4E},
    { 83,0x00},
    { 84,0x10},
    { 85,0x14},
    { 86,0x4F},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x08},
    { 93,0x00},
    { 94,0x03},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x88},
    {101,0x03},
    {102,0xFF},
    {103,0x00},
};
#define miniDSP_A_reg_values_COEFF_START   0
#define miniDSP_A_reg_values_COEFF_SIZE    372
#define miniDSP_A_reg_values_INST_START    372
#define miniDSP_A_reg_values_INST_SIZE     460

reg_value miniDSP_D_reg_values[] = {
    {  0,0x2C},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xF7},
    { 18,0x00},
    { 19,0x00},
    { 20,0x80},
    { 21,0x09},
    { 22,0x00},
    { 23,0x00},
    { 24,0x7F},
    { 25,0xEF},
    { 26,0x00},
    { 27,0x00},
    { 28,0x7F},
    { 29,0xB2},
    { 30,0x60},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x01},
    { 35,0x00},
    { 36,0x40},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x7F},
    { 41,0xFF},
    { 42,0xFF},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0xC0},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFF},
    { 61,0xDC},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFF},
    { 65,0xC0},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x0A},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x7B},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFD},
    { 77,0x21},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFE},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFA},
    { 85,0xBE},
    { 86,0x00},
    { 87,0x00},
    { 88,0xF2},
    { 89,0xAB},
    { 90,0x00},
    { 91,0x00},
    { 92,0x28},
    { 93,0xA9},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x29},
    { 98,0x00},
    { 99,0x00},
    {100,0x02},
    {101,0x30},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0xB7},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x5E},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x47},
    {114,0x00},
    {115,0x00},
    {116,0x03},
    {117,0xD3},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xBD},
    {122,0x00},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x2D},
    {  8,0x14},
    {  9,0xEF},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0xEF},
    { 14,0x00},
    { 15,0x00},
    { 16,0x01},
    { 17,0x86},
    { 18,0x00},
    { 19,0x00},
    { 20,0x2B},
    { 21,0xE8},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFE},
    { 25,0x88},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x15},
    { 30,0x00},
    { 31,0x00},
    { 32,0xF8},
    { 33,0xF9},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x3D},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x52},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0xBC},
    { 47,0x00},
    {  0,0x3E},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xF7},
    { 18,0x00},
    { 19,0x00},
    { 20,0x80},
    { 21,0x09},
    { 22,0x00},
    { 23,0x00},
    { 24,0x7F},
    { 25,0xEF},
    { 26,0x00},
    { 27,0x00},
    { 28,0x7F},
    { 29,0xB2},
    { 30,0x60},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x01},
    { 35,0x00},
    { 36,0x40},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x7F},
    { 41,0xFF},
    { 42,0xFF},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0xC0},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFF},
    { 61,0xDC},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFF},
    { 65,0xC0},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x0A},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFF},
    { 73,0x7B},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFD},
    { 77,0x21},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFE},
    { 81,0x54},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFA},
    { 85,0xBE},
    { 86,0x00},
    { 87,0x00},
    { 88,0xF2},
    { 89,0xAB},
    { 90,0x00},
    { 91,0x00},
    { 92,0x28},
    { 93,0xA9},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x29},
    { 98,0x00},
    { 99,0x00},
    {100,0x02},
    {101,0x30},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0xB7},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x5E},
    {110,0x00},
    {111,0x00},
    {112,0x01},
    {113,0x47},
    {114,0x00},
    {115,0x00},
    {116,0x03},
    {117,0xD3},
    {118,0x00},
    {119,0x00},
    {120,0x07},
    {121,0xBD},
    {122,0x00},
    {123,0x00},
    {124,0x40},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x3F},
    {  8,0x14},
    {  9,0xEF},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0xEF},
    { 14,0x00},
    { 15,0x00},
    { 16,0x01},
    { 17,0x86},
    { 18,0x00},
    { 19,0x00},
    { 20,0x2B},
    { 21,0xE8},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFE},
    { 25,0x88},
    { 26,0x00},
    { 27,0x00},
    { 28,0xFE},
    { 29,0x15},
    { 30,0x00},
    { 31,0x00},
    { 32,0xF8},
    { 33,0xF9},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x3D},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x52},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0xBC},
    { 47,0x00},
    {  0,0x98},
    {  8,0x08},
    {  9,0x08},
    { 10,0x00},
    { 11,0x00},
    { 12,0x08},
    { 13,0x0C},
    { 14,0x01},
    { 15,0x00},
    { 16,0x08},
    { 17,0x00},
    { 18,0x08},
    { 19,0x00},
    { 20,0x08},
    { 21,0x04},
    { 22,0x09},
    { 23,0x00},
    { 24,0x30},
    { 25,0x0C},
    { 26,0x43},
    { 27,0x00},
    { 28,0x38},
    { 29,0x10},
    { 30,0x47},
    { 31,0x00},
    { 32,0x38},
    { 33,0x08},
    { 34,0x42},
    { 35,0x00},
    { 36,0x30},
    { 37,0x0C},
    { 38,0x14},
    { 39,0x00},
    { 40,0x38},
    { 41,0x10},
    { 42,0x18},
    { 43,0x00},
    { 44,0x28},
    { 45,0x00},
    { 46,0x46},
    { 47,0x00},
    { 48,0x38},
    { 49,0x08},
    { 50,0x13},
    { 51,0x00},
    { 52,0x10},
    { 53,0x00},
    { 54,0x3E},
    { 55,0x00},
    { 56,0x30},
    { 57,0x34},
    { 58,0x36},
    { 59,0x00},
    { 60,0xA0},
    { 61,0x34},
    { 62,0x17},
    { 63,0x00},
    { 64,0x10},
    { 65,0x04},
    { 66,0x6D},
    { 67,0x00},
    { 68,0x38},
    { 69,0x38},
    { 70,0x34},
    { 71,0x00},
    { 72,0x38},
    { 73,0x38},
    { 74,0x19},
    { 75,0x00},
    { 76,0x38},
    { 77,0x3C},
    { 78,0x30},
    { 79,0x00},
    { 80,0x38},
    { 81,0x3C},
    { 82,0x1D},
    { 83,0x00},
    { 84,0x38},
    { 85,0x40},
    { 86,0x32},
    { 87,0x00},
    { 88,0x38},
    { 89,0x40},
    { 90,0x1B},
    { 91,0x00},
    { 92,0x38},
    { 93,0x44},
    { 94,0x2C},
    { 95,0x00},
    { 96,0x38},
    { 97,0x44},
    { 98,0x21},
    { 99,0x00},
    {100,0x38},
    {101,0x48},
    {102,0x2E},
    {103,0x00},
    {104,0x38},
    {105,0x48},
    {106,0x1F},
    {107,0x00},
    {108,0x38},
    {109,0x4C},
    {110,0x2A},
    {111,0x00},
    {112,0x38},
    {113,0x4C},
    {114,0x23},
    {115,0x00},
    {116,0x38},
    {117,0x50},
    {118,0x28},
    {119,0x00},
    {120,0x38},
    {121,0x50},
    {122,0x25},
    {123,0x00},
    {124,0x38},
    {125,0x54},
    {126,0x27},
    {127,0x00},
    {  0,0x99},
    {  8,0x38},
    {  9,0x54},
    { 10,0x26},
    { 11,0x00},
    { 12,0x38},
    { 13,0x58},
    { 14,0x35},
    { 15,0x00},
    { 16,0x38},
    { 17,0x58},
    { 18,0x18},
    { 19,0x00},
    { 20,0x38},
    { 21,0x5C},
    { 22,0x2D},
    { 23,0x00},
    { 24,0x38},
    { 25,0x5C},
    { 26,0x20},
    { 27,0x00},
    { 28,0x38},
    { 29,0x60},
    { 30,0x31},
    { 31,0x00},
    { 32,0x38},
    { 33,0x60},
    { 34,0x1C},
    { 35,0x00},
    { 36,0x38},
    { 37,0x64},
    { 38,0x33},
    { 39,0x00},
    { 40,0x38},
    { 41,0x64},
    { 42,0x1A},
    { 43,0x00},
    { 44,0x38},
    { 45,0x68},
    { 46,0x2F},
    { 47,0x00},
    { 48,0x38},
    { 49,0x68},
    { 50,0x1E},
    { 51,0x00},
    { 52,0x38},
    { 53,0x6C},
    { 54,0x2B},
    { 55,0x00},
    { 56,0x38},
    { 57,0x6C},
    { 58,0x22},
    { 59,0x00},
    { 60,0x38},
    { 61,0x70},
    { 62,0x29},
    { 63,0x00},
    { 64,0x38},
    { 65,0x70},
    { 66,0x24},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x30},
    { 73,0x34},
    { 74,0x65},
    { 75,0x00},
    { 76,0x20},
    { 77,0x00},
    { 78,0x3A},
    { 79,0x00},
    { 80,0x38},
    { 81,0x34},
    { 82,0x46},
    { 83,0x00},
    { 84,0x38},
    { 85,0x38},
    { 86,0x63},
    { 87,0x00},
    { 88,0x38},
    { 89,0x38},
    { 90,0x48},
    { 91,0x00},
    { 92,0x38},
    { 93,0x3C},
    { 94,0x5F},
    { 95,0x00},
    { 96,0x38},
    { 97,0x3C},
    { 98,0x4C},
    { 99,0x00},
    {100,0x38},
    {101,0x40},
    {102,0x61},
    {103,0x00},
    {104,0x38},
    {105,0x40},
    {106,0x4A},
    {107,0x00},
    {108,0x38},
    {109,0x44},
    {110,0x5B},
    {111,0x00},
    {112,0x38},
    {113,0x44},
    {114,0x50},
    {115,0x00},
    {116,0x38},
    {117,0x48},
    {118,0x5D},
    {119,0x00},
    {120,0x38},
    {121,0x48},
    {122,0x4E},
    {123,0x00},
    {124,0x38},
    {125,0x4C},
    {126,0x59},
    {127,0x00},
    {  0,0x9A},
    {  8,0x38},
    {  9,0x4C},
    { 10,0x52},
    { 11,0x00},
    { 12,0x38},
    { 13,0x50},
    { 14,0x57},
    { 15,0x00},
    { 16,0x38},
    { 17,0x50},
    { 18,0x54},
    { 19,0x00},
    { 20,0x38},
    { 21,0x54},
    { 22,0x56},
    { 23,0x00},
    { 24,0x38},
    { 25,0x54},
    { 26,0x55},
    { 27,0x00},
    { 28,0x38},
    { 29,0x58},
    { 30,0x64},
    { 31,0x00},
    { 32,0x38},
    { 33,0x58},
    { 34,0x47},
    { 35,0x00},
    { 36,0x38},
    { 37,0x5C},
    { 38,0x5C},
    { 39,0x00},
    { 40,0x38},
    { 41,0x5C},
    { 42,0x4F},
    { 43,0x00},
    { 44,0x38},
    { 45,0x60},
    { 46,0x60},
    { 47,0x00},
    { 48,0x38},
    { 49,0x60},
    { 50,0x4B},
    { 51,0x00},
    { 52,0x38},
    { 53,0x64},
    { 54,0x62},
    { 55,0x00},
    { 56,0x38},
    { 57,0x64},
    { 58,0x49},
    { 59,0x00},
    { 60,0x38},
    { 61,0x68},
    { 62,0x5E},
    { 63,0x00},
    { 64,0x38},
    { 65,0x68},
    { 66,0x4D},
    { 67,0x00},
    { 68,0x38},
    { 69,0x6C},
    { 70,0x5A},
    { 71,0x00},
    { 72,0x38},
    { 73,0x6C},
    { 74,0x51},
    { 75,0x00},
    { 76,0x38},
    { 77,0x70},
    { 78,0x58},
    { 79,0x00},
    { 80,0x38},
    { 81,0x70},
    { 82,0x53},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x30},
    { 89,0x78},
    { 90,0x6B},
    { 91,0x00},
    { 92,0x98},
    { 93,0x7C},
    { 94,0x69},
    { 95,0x00},
    { 96,0x38},
    { 97,0x80},
    { 98,0x6C},
    { 99,0x00},
    {100,0x38},
    {101,0x84},
    {102,0x67},
    {103,0x00},
    {104,0x38},
    {105,0x88},
    {106,0x6A},
    {107,0x00},
    {108,0x38},
    {109,0x8C},
    {110,0x66},
    {111,0x00},
    {112,0x38},
    {113,0x90},
    {114,0x68},
    {115,0x00},
    {116,0x00},
    {117,0x04},
    {118,0x00},
    {119,0x00},
    {120,0x50},
    {121,0x04},
    {122,0x02},
    {123,0x00},
    {124,0x30},
    {125,0x78},
    {126,0x3C},
    {127,0x00},
    {  0,0x9B},
    {  8,0x38},
    {  9,0x7C},
    { 10,0x3A},
    { 11,0x00},
    { 12,0x20},
    { 13,0x08},
    { 14,0x6F},
    { 15,0x00},
    { 16,0x38},
    { 17,0x80},
    { 18,0x3D},
    { 19,0x00},
    { 20,0x38},
    { 21,0x84},
    { 22,0x38},
    { 23,0x00},
    { 24,0x38},
    { 25,0x88},
    { 26,0x3B},
    { 27,0x00},
    { 28,0x38},
    { 29,0x8C},
    { 30,0x37},
    { 31,0x00},
    { 32,0x38},
    { 33,0x90},
    { 34,0x39},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x50},
    { 41,0x00},
    { 42,0x02},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x20},
    { 53,0x08},
    { 54,0x40},
    { 55,0x00},
    { 56,0x30},
    { 57,0x1C},
    { 58,0x00},
    { 59,0x00},
    { 60,0x30},
    { 61,0x1C},
    { 62,0x02},
    { 63,0x00},
    { 64,0x30},
    { 65,0x27},
    { 66,0xFB},
    { 67,0x00},
    { 68,0x20},
    { 69,0x04},
    { 70,0x03},
    { 71,0x00},
    { 72,0x20},
    { 73,0x04},
    { 74,0x04},
    { 75,0x00},
    { 76,0x20},
    { 77,0x04},
    { 78,0x05},
    { 79,0x00},
    { 80,0x30},
    { 81,0x1B},
    { 82,0xFB},
    { 83,0x00},
    { 84,0x38},
    { 85,0x03},
    { 86,0xFB},
    { 87,0x00},
    { 88,0x20},
    { 89,0x04},
    { 90,0x06},
    { 91,0x00},
    { 92,0x48},
    { 93,0x1C},
    { 94,0x0F},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x18},
    {101,0xF0},
    {102,0x02},
    {103,0x00},
    {104,0x90},
    {105,0x7C},
    {106,0x00},
    {107,0x00},
    {108,0x30},
    {109,0x1C},
    {110,0x03},
    {111,0x00},
    {112,0x90},
    {113,0xFC},
    {114,0x00},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x20},
    {121,0x04},
    {122,0x07},
    {123,0x00},
    {124,0x30},
    {125,0x17},
    {126,0xFB},
    {127,0x00},
    {  0,0x9C},
    {  8,0x80},
    {  9,0x30},
    { 10,0x11},
    { 11,0x00},
    { 12,0x38},
    { 13,0x30},
    { 14,0x0F},
    { 15,0x00},
    { 16,0x20},
    { 17,0x04},
    { 18,0x10},
    { 19,0x00},
    { 20,0x88},
    { 21,0x08},
    { 22,0x06},
    { 23,0x00},
    { 24,0x20},
    { 25,0xDC},
    { 26,0x0D},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x30},
    { 37,0x1C},
    { 38,0x0F},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x88},
    { 45,0x00},
    { 46,0x17},
    { 47,0x00},
    { 48,0x30},
    { 49,0x1C},
    { 50,0x0D},
    { 51,0x00},
    { 52,0x80},
    { 53,0x27},
    { 54,0xFB},
    { 55,0x00},
    { 56,0x38},
    { 57,0x1C},
    { 58,0x0F},
    { 59,0x00},
    { 60,0x80},
    { 61,0x30},
    { 62,0x10},
    { 63,0x00},
    { 64,0x88},
    { 65,0x18},
    { 66,0x09},
    { 67,0x00},
    { 68,0x88},
    { 69,0x08},
    { 70,0x11},
    { 71,0x00},
    { 72,0x20},
    { 73,0x04},
    { 74,0x0E},
    { 75,0x00},
    { 76,0x88},
    { 77,0x10},
    { 78,0x11},
    { 79,0x00},
    { 80,0x30},
    { 81,0x1C},
    { 82,0x10},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x30},
    { 89,0x27},
    { 90,0xFB},
    { 91,0x00},
    { 92,0x20},
    { 93,0x04},
    { 94,0x0E},
    { 95,0x00},
    { 96,0x40},
    { 97,0x28},
    { 98,0x02},
    { 99,0x00},
    {100,0x88},
    {101,0x00},
    {102,0x11},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x20},
    {109,0x04},
    {110,0x0E},
    {111,0x00},
    {112,0x88},
    {113,0x0C},
    {114,0x08},
    {115,0x00},
    {116,0x30},
    {117,0x1C},
    {118,0x10},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x30},
    {125,0x27},
    {126,0xFB},
    {127,0x00},
    {  0,0x9D},
    {  8,0x20},
    {  9,0x04},
    { 10,0x0E},
    { 11,0x00},
    { 12,0x40},
    { 13,0x28},
    { 14,0x02},
    { 15,0x00},
    { 16,0x88},
    { 17,0x00},
    { 18,0x08},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x20},
    { 25,0x04},
    { 26,0x0E},
    { 27,0x00},
    { 28,0x40},
    { 29,0x28},
    { 30,0x02},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x30},
    { 41,0x1C},
    { 42,0x0D},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x20},
    { 53,0x04},
    { 54,0x0C},
    { 55,0x00},
    { 56,0x30},
    { 57,0x28},
    { 58,0x08},
    { 59,0x00},
    { 60,0x30},
    { 61,0x28},
    { 62,0x09},
    { 63,0x00},
    { 64,0x30},
    { 65,0x2B},
    { 66,0xFB},
    { 67,0x00},
    { 68,0x20},
    { 69,0x04},
    { 70,0x0A},
    { 71,0x00},
    { 72,0x20},
    { 73,0x04},
    { 74,0x0B},
    { 75,0x00},
    { 76,0x40},
    { 77,0x2C},
    { 78,0x3F},
    { 79,0x00},
    { 80,0x30},
    { 81,0x97},
    { 82,0xFB},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x38},
    { 89,0x03},
    { 90,0xFB},
    { 91,0x00},
    { 92,0x88},
    { 93,0x17},
    { 94,0xFE},
    { 95,0x00},
    { 96,0x10},
    { 97,0x00},
    { 98,0x40},
    { 99,0x00},
    {100,0x10},
    {101,0x04},
    {102,0x6F},
    {103,0x00},
    {104,0x30},
    {105,0x78},
    {106,0x6A},
    {107,0x00},
    {108,0x38},
    {109,0x7C},
    {110,0x6C},
    {111,0x00},
    {112,0x38},
    {113,0x80},
    {114,0x69},
    {115,0x00},
    {116,0x38},
    {117,0x84},
    {118,0x67},
    {119,0x00},
    {120,0x38},
    {121,0x88},
    {122,0x6B},
    {123,0x00},
    {124,0x38},
    {125,0x8C},
    {126,0x68},
    {127,0x00},
    {  0,0x9E},
    {  8,0x38},
    {  9,0x90},
    { 10,0x66},
    { 11,0x00},
    { 12,0x00},
    { 13,0x04},
    { 14,0x00},
    { 15,0x00},
    { 16,0x50},
    { 17,0x04},
    { 18,0x02},
    { 19,0x00},
    { 20,0x30},
    { 21,0x78},
    { 22,0x3B},
    { 23,0x00},
    { 24,0x38},
    { 25,0x7C},
    { 26,0x3D},
    { 27,0x00},
    { 28,0x20},
    { 29,0x08},
    { 30,0x6E},
    { 31,0x00},
    { 32,0x38},
    { 33,0x80},
    { 34,0x3A},
    { 35,0x00},
    { 36,0x38},
    { 37,0x84},
    { 38,0x38},
    { 39,0x00},
    { 40,0x38},
    { 41,0x88},
    { 42,0x3C},
    { 43,0x00},
    { 44,0x38},
    { 45,0x8C},
    { 46,0x39},
    { 47,0x00},
    { 48,0x38},
    { 49,0x90},
    { 50,0x37},
    { 51,0x00},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x50},
    { 57,0x00},
    { 58,0x02},
    { 59,0x00},
    { 60,0x30},
    { 61,0x74},
    { 62,0x55},
    { 63,0x00},
    { 64,0x30},
    { 65,0x78},
    { 66,0x67},
    { 67,0x00},
    { 68,0x20},
    { 69,0x08},
    { 70,0x3F},
    { 71,0x00},
    { 72,0x98},
    { 73,0x7C},
    { 74,0x65},
    { 75,0x00},
    { 76,0x38},
    { 77,0x80},
    { 78,0x68},
    { 79,0x00},
    { 80,0x38},
    { 81,0x84},
    { 82,0x6A},
    { 83,0x00},
    { 84,0x38},
    { 85,0x88},
    { 86,0x66},
    { 87,0x00},
    { 88,0x38},
    { 89,0x8C},
    { 90,0x69},
    { 91,0x00},
    { 92,0x38},
    { 93,0x90},
    { 94,0x6B},
    { 95,0x00},
    { 96,0x00},
    { 97,0x04},
    { 98,0x00},
    { 99,0x00},
    {100,0x50},
    {101,0x04},
    {102,0x02},
    {103,0x00},
    {104,0x30},
    {105,0x74},
    {106,0x26},
    {107,0x00},
    {108,0x30},
    {109,0x78},
    {110,0x38},
    {111,0x00},
    {112,0x20},
    {113,0x08},
    {114,0x6D},
    {115,0x00},
    {116,0x98},
    {117,0x7C},
    {118,0x36},
    {119,0x00},
    {120,0x38},
    {121,0x80},
    {122,0x39},
    {123,0x00},
    {124,0x38},
    {125,0x84},
    {126,0x3B},
    {127,0x00},
    {  0,0x9F},
    {  8,0x38},
    {  9,0x88},
    { 10,0x37},
    { 11,0x00},
    { 12,0x38},
    { 13,0x8C},
    { 14,0x3A},
    { 15,0x00},
    { 16,0x38},
    { 17,0x90},
    { 18,0x3C},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x50},
    { 25,0x00},
    { 26,0x02},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x20},
    { 37,0x08},
    { 38,0x3E},
    { 39,0x00},
    { 40,0x30},
    { 41,0x9B},
    { 42,0xFB},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x38},
    { 49,0x03},
    { 50,0xFB},
    { 51,0x00},
    { 52,0x88},
    { 53,0x17},
    { 54,0xFE},
    { 55,0x00},
    { 56,0x00},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x10},
    { 61,0x00},
    { 62,0x3F},
    { 63,0x00},
    { 64,0x10},
    { 65,0x04},
    { 66,0x6E},
    { 67,0x00},
    { 68,0x30},
    { 69,0x78},
    { 70,0x66},
    { 71,0x00},
    { 72,0x38},
    { 73,0x7C},
    { 74,0x68},
    { 75,0x00},
    { 76,0x38},
    { 77,0x80},
    { 78,0x65},
    { 79,0x00},
    { 80,0x38},
    { 81,0x84},
    { 82,0x6A},
    { 83,0x00},
    { 84,0x38},
    { 85,0x88},
    { 86,0x67},
    { 87,0x00},
    { 88,0x38},
    { 89,0x8C},
    { 90,0x6B},
    { 91,0x00},
    { 92,0x38},
    { 93,0x90},
    { 94,0x69},
    { 95,0x00},
    { 96,0x00},
    { 97,0x04},
    { 98,0x00},
    { 99,0x00},
    {100,0x50},
    {101,0x04},
    {102,0x02},
    {103,0x00},
    {104,0x30},
    {105,0x78},
    {106,0x37},
    {107,0x00},
    {108,0x38},
    {109,0x7C},
    {110,0x39},
    {111,0x00},
    {112,0x20},
    {113,0x08},
    {114,0x6C},
    {115,0x00},
    {116,0x38},
    {117,0x80},
    {118,0x36},
    {119,0x00},
    {120,0x38},
    {121,0x84},
    {122,0x3B},
    {123,0x00},
    {124,0x38},
    {125,0x88},
    {126,0x38},
    {127,0x00},
    {  0,0xA0},
    {  8,0x38},
    {  9,0x8C},
    { 10,0x3C},
    { 11,0x00},
    { 12,0x38},
    { 13,0x90},
    { 14,0x3A},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x50},
    { 21,0x00},
    { 22,0x02},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x20},
    { 33,0x08},
    { 34,0x3D},
    { 35,0x00},
    { 36,0x30},
    { 37,0x9F},
    { 38,0xFB},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x38},
    { 45,0x03},
    { 46,0xFB},
    { 47,0x00},
    { 48,0x88},
    { 49,0x17},
    { 50,0xFE},
    { 51,0x00},
    { 52,0x30},
    { 53,0x1C},
    { 54,0x07},
    { 55,0x00},
    { 56,0x30},
    { 57,0x1C},
    { 58,0x0B},
    { 59,0x00},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x20},
    { 65,0x04},
    { 66,0x12},
    { 67,0x00},
    { 68,0x20},
    { 69,0x04},
    { 70,0x41},
    { 71,0x00},
    { 72,0x10},
    { 73,0x00},
    { 74,0x3E},
    { 75,0x00},
    { 76,0x10},
    { 77,0x04},
    { 78,0x6D},
    { 79,0x00},
    { 80,0x88},
    { 81,0x03},
    { 82,0xFF},
    { 83,0x00},
};
#define miniDSP_D_reg_values_COEFF_START   0
#define miniDSP_D_reg_values_COEFF_SIZE    324
#define miniDSP_D_reg_values_INST_START    324
#define miniDSP_D_reg_values_INST_SIZE     1045
